filename ="../Data/Wave1.csv"
outname ="../Data/Wave1_clean.csv"
data = read.csv(filename)
attach(data)


###########
#Remove variables we don't need to include
#(Some - mostly weights - already removed, but will not affect code if they are missing)
###########
drop = which(names(data) %in% c("idnum","mothid1","m1intmon","m1intyr","m1lenhr","m1lenmin","cm1twoc","cm1fint","cm1natsm","m1natwt",
                                "cm1natsmx","m1natwtx","cm1citsm","m1citywt","innatsm","incitysm","m1a8","f1citywt","cf1citsm",
                                "f1natwtx","cf1natsmx","f1natwt","cf1natsm","cf1twoc","f1lenmin","f1lenhr","f1intyr","f1intmon",
                                "fathid1", "cm1tdiff"))
newdata = data[,-drop]  #note that if you need to drop more, add them to the above, or replace names(data) with names(newdata), or indices won't line up.


###########
#Checking equivalencies
###########
#marital status variables:
table(m1a4,m1a10, useNA = "ifany")
#Note that one respondent has m1a4 = 2 (not married) and m1a10 = 1 (married)
table(m1b2,m1a10, useNA = "ifany")
#One respondent has m1b2 = 2 (not married) and m1a10 = 1 (married)
table(m1a4, m1b2, useNA = "ifany")
#All in agreement.  Suggests the error is in m1a10 - use m1a4 when evaluating marital status

#father unknown variables:
table(m1a4, m1b0, useNA = "ifany")
#18 subjects who responded m1a4 = 2 (not married) with m1b0 = 1 (father unknown)
#Trust initial report, not interviewer recall (use m1a4) - means Section B q's will need to be coded missing (-3) in place of skip (-6) for these 18



###########
#Skip recodes
###########

newdata$m1a5[m1a4==3] = 2 #(father unkown means baby won't have last name)
newdata$m1a5[m1a4==1] = 1 #(skipped last name if married - assumed yes)

newdata$m1a6[m1a4==3] = 2 #(father unkown means won't be on certificate)
newdata$m1a6[m1a4==1] = 1 #(skipped if married - assumed yes)

newdata$m1a7[m1a4==3] = 2 #(father unkown wouldn't visit)

newdata$m1a11a[m1a4==1] = 1 #(assume baby lives with both married parents)
newdata$m1a11b[m1a4==1] = 1 #(assume baby lives with both married parents)

newdata$m1a12a[m1a12==2] = 0 #(reported no other children, so no siblings)

#m1a13a (month of 1st doctor visit) all missing

#cm1lbw - low birth weight.  Skipped when cm1numb = 2(twin birth).  Leave missing
                         
newdata$m1b1a[m1a4==3] = 0 #(known 0 years if father unknown)
newdata$m1b1b[m1a4==3] = 0 #(known 0 months if father unknown)
newdata$m1b1a[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b1b[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)

newdata$m1b3[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)

newdata$m1b4a[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4b[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4c[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4d[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4e[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4f[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4g[m1a4 == 1 | m1a4 == 3 | m1b3 == 1 | m1b3 == 2] = 3 #(didn't end if still married or never started)
newdata$m1b4a[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b4b[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b4c[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b4d[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b4e[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b4f[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b4g[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)

newdata$m1b5a[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b5b[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b5c[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b5d[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)

newdata$m1b6a[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b6b[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b6c[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b6d[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b6e[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b6f[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)

newdata$m1b7a[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b7b[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b7c[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b7d[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b7e[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)

newdata$m1b8[m1a4 == 3] = 2 #(not living together if unknown) 
newdata$m1b8[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b8[m1a4 == 1] = 1 #(assume live together if married)
newdata$m1b8[m1b3 > 2] = 2 #(not living together if reln ended)

newdata$m1b9[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9[m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9[m1a4 == 1] = 0 #(assume married are living together)
newdata$m1b9[m1b3 > 2] = 2 #Assume if rel'n has ended they are not living together

newdata$m1b9a1[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a1[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a1[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a1[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a1[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a2[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a2[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a2[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a2[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a2[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a3[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a3[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a3[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a3[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a3[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a4[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a4[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a4[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a4[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a4[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a5[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a5[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a5[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a5[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a5[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a6[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a6[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a6[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a6[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a6[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a7[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a7[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a7[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a7[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a7[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a8[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a8[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a8[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a8[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a8[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a9[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a9[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a9[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a9[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a9[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a10[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a10[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a10[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a10[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a10[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9a11[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9a11[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9a11[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9a11[newdata$m1b9 == 1] = 4 #(add level for are planning)
newdata$m1b9a11[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b1[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b1[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b1[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b1[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b1[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b2[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b2[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b2[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b2[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b2[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b3[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b3[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b3[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b3[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b3[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b4[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b4[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b4[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b4[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b4[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b5[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b5[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b5[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b5[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b5[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b6[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b6[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b6[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b6[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b6[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b7[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b7[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b7[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b7[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b7[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b8[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b8[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b8[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b8[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b8[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b9[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b9[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b9[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b9[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b9[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b10[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b10[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b10[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b10[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b10[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b9b11[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b9b11[newdata$m1b8 == 1] = 0 #(make factor and add level for already living together)
newdata$m1b9b11[m1a4 == 3] = 3 #(add level for never b/c unknown)
newdata$m1b9b11[newdata$m1b9 == 2] = 4 #(add level for not planning) 
newdata$m1b9b11[m1b3 >2] = 5 #(add level for no b/c rel'n ended)

newdata$m1b10[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10[m1a4 == 3] = 3 #(won't plan to marry unknown father)
newdata$m1b10[m1b3 >2] = 3 #(add level for no b/c rel'n ended)
newdata$m1b10[m1b9==2] = 2 #(assume not planning to marry if answered no to marry or live together)

newdata$m1b10a1[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a1[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a1[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a1[m1b3 >2] = 3 #(add level for no b/c rel'n ended

newdata$m1b10a2[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a2[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a2[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a2[m1b3 >2] = 3 #(add level for no b/c rel'n ended

newdata$m1b10a3[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a3[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a3[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a3[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a4[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a4[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a4[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a4[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a5[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a5[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a5[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a5[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a6[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a6[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a6[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a6[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a7[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a7[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a7[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a7[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a8[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a8[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a8[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a8[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a9[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a9[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a9[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a9[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a10[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a10[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a10[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a10[m1b3 >2] = 3 #(add level for no b/c rel'n ended  

newdata$m1b10a11[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10a11[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10a11[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10a11[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b1[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b1[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b1[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b1[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b2[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b2[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b2[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b2[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b3[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b3[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b3[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b3[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b4[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b4[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b4[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b4[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b5[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b5[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b5[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b5[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b6[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b6[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b6[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b6[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b7[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b7[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b7[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b7[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b8[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b8[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b8[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b8[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b9[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b9[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b9[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b9[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b10[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b10[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b10[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b10[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

newdata$m1b10b11[m1a4 == 2 & m1b0 == 1] = -3 #(missing if miscoded father unknown)
newdata$m1b10b11[m1a4 == 1] = 0 #(make factor and add level for already married)
newdata$m1b10b11[m1a4 == 3] = 3 #(add level for unknown father)
newdata$m1b10b11[m1b3 >2] = 3 #(add level for no b/c rel'n ended                            

###########
#Create factors when important
###########
#m1a4 - married/unmarried/unknown
newdata$m1a4[m1a4 == -9] = NA
newdata$m1a4 = factor(newdata$m1a4)

#m1a5 - baby have father's last name
newdata$m1a5[newdata$m1b9 %in% c(-9, -3, -1)] = NA
newdata$m1a5 = factor(newdata$m1a5)

#m1a6 - father's name of birth certificate
newdata$m1a6[newdata$m1a16 %in% c(-9, -3, -1)] = NA
newdata$m1a6 = factor(newdata$m1a6)

#m1a15 - how paying for birth
table(m1a15)
newdata$m1a15[newdata$m1a15 %in% c(-9, -3, -1)] = NA
newdata$m1a15 = factor(newdata$m1a15)

#m1b4a-g : why did rel end? 
table(newdata$m1b4a)
newdata$m1b4a[newdata$m1b4a %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4a = factor(newdata$m1b4a)
newdata$m1b4b[newdata$m1b4b %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4b = factor(newdata$m1b4b)
newdata$m1b4c[newdata$m1b4c %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4c = factor(newdata$m1b4c)
newdata$m1b4d[newdata$m1b4d %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4d = factor(newdata$m1b4d)
newdata$m1b4e[newdata$m1b4e %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4e = factor(newdata$m1b4e)
newdata$m1b4f[newdata$m1b4f %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4f = factor(newdata$m1b4f)
newdata$m1b4g[newdata$m1b4g %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$m1b4g = factor(newdata$m1b4g)

#m1b9 - plans to live together?  0 = already do, 1 = yes, 2 = no, 3 = father unknown
table(newdata$m1b9)  
newdata$m1b9[newdata$m1b9 %in% c(-9, -6, -5, -3, -2)] = NA
newdata$m1b9 = factor(newdata$m1b9)

#m1b9a1-m1b9a11  
table(newdata$m1b9a1)
newdata$m1b9a1[newdata$m1b9a1 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a1 = factor(newdata$m1b9a1)
newdata$m1b9a2[newdata$m1b9a2 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a2 = factor(newdata$m1b9a2)
newdata$m1b9a3[newdata$m1b9a3 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a3 = factor(newdata$m1b9a3)
newdata$m1b9a4[newdata$m1b9a4 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a4 = factor(newdata$m1b9a4)
newdata$m1b9a5[newdata$m1b9a5 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a5 = factor(newdata$m1b9a5)
newdata$m1b9a6[newdata$m1b9a6 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a6 = factor(newdata$m1b9a6)
newdata$m1b9a7[newdata$m1b9a7 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a7 = factor(newdata$m1b9a7)
newdata$m1b9a8[newdata$m1b9a8 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a8 = factor(newdata$m1b9a8)
newdata$m1b9a9[newdata$m1b9a9 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a9 = factor(newdata$m1b9a9)
newdata$m1b9a10[newdata$m1b9a10 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a10 = factor(newdata$m1b9a10)
newdata$m1b9a11[newdata$m1b9a11 %in% c(-9, -6, -5, -3)] = NA
newdata$m1b9a11 = factor(newdata$m1b9a11)

#m1b9b1-m1b9b11 
table(newdata$m1b9b1)
newdata$m1b9b1[newdata$m1b9b1 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b1 = factor(newdata$m1b9b1)
newdata$m1b9b2[newdata$m1b9b2 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b2 = factor(newdata$m1b9b2)
newdata$m1b9b3[newdata$m1b9b3 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b3 = factor(newdata$m1b9b3)
newdata$m1b9b4[newdata$m1b9b4 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b4 = factor(newdata$m1b9b4)
newdata$m1b9b5[newdata$m1b9b5 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b5 = factor(newdata$m1b9b5)
newdata$m1b9b6[newdata$m1b9b6 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b6 = factor(newdata$m1b9b6)
newdata$m1b9b7[newdata$m1b9b7 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b7 = factor(newdata$m1b9b7)
newdata$m1b9b8[newdata$m1b9b8 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b8 = factor(newdata$m1b9b8)
newdata$m1b9b9[newdata$m1b9b9 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b9 = factor(newdata$m1b9b9)
newdata$m1b9b10[newdata$m1b9b10 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b10 = factor(newdata$m1b9b10)
newdata$m1b9b11[newdata$m1b9b11 %in% c(-9, -6, -5, -3, -1)] = NA
newdata$m1b9b11 = factor(newdata$m1b9b11)

#m1b10   
table(newdata$m1b10)
newdata$m1b10[newdata$m1b10 %in% c(-9, -5, -3, -2, -1)] = NA
newdata$m1b10 = factor(newdata$m1b10)

#m1b10a1-m1b10a11
table(newdata$m1b10a1)
newdata$m1b10a1[newdata$m1b10a1 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a1 = factor(newdata$m1b10a1)
newdata$m1b10a2[newdata$m1b10a2 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a2 = factor(newdata$m1b10a2)
newdata$m1b10a3[newdata$m1b10a3 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a3 = factor(newdata$m1b10a3)
newdata$m1b10a4[newdata$m1b10a4 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a4 = factor(newdata$m1b10a4)
newdata$m1b10a5[newdata$m1b10a5 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a5 = factor(newdata$m1b10a5)
newdata$m1b10a6[newdata$m1b10a6 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a6 = factor(newdata$m1b10a6)
newdata$m1b10a7[newdata$m1b10a7 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a7 = factor(newdata$m1b10a7)
newdata$m1b10a8[newdata$m1b10a8 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a8 = factor(newdata$m1b10a8)
newdata$m1b10a9[newdata$m1b10a9 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a9 = factor(newdata$m1b10a9)
newdata$m1b10a10[newdata$m1b10a10 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a10 = factor(newdata$m1b10a10)
newdata$m1b10a11[newdata$m1b10a11 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10a11 = factor(newdata$m1b10a11)

#m1b10b1-m1b10b11
table(newdata$m1b10b1)
newdata$m1b10b1[newdata$m1b10b1 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b1 = factor(newdata$m1b10b1)
newdata$m1b10b2[newdata$m1b10b2 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b2 = factor(newdata$m1b10b2)
newdata$m1b10b3[newdata$m1b10b3 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b3 = factor(newdata$m1b10b3)
newdata$m1b10b4[newdata$m1b10b4 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b4 = factor(newdata$m1b10b4)
newdata$m1b10b5[newdata$m1b10b5 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b5 = factor(newdata$m1b10b5)
newdata$m1b10b6[newdata$m1b10b6 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b6 = factor(newdata$m1b10b6)
newdata$m1b10b7[newdata$m1b10b7 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b7 = factor(newdata$m1b10b7)
newdata$m1b10b8[newdata$m1b10b8 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b8 = factor(newdata$m1b10b8)
newdata$m1b10b9[newdata$m1b10b9 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b9 = factor(newdata$m1b10b9)
newdata$m1b10b10[newdata$m1b10b10 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b10 = factor(newdata$m1b10b10)
newdata$m1b10b11[newdata$m1b10b11 %in% c(-9, -5, -3, -1)] = NA
newdata$m1b10b11 = factor(newdata$m1b10b11)

#m1a16 - who does baby look like?  DK (-2) can be category
table(m1a16)
newdata$m1a16[m1a16 %in% c(-9, -3)] = NA  #make sure missing values don't become a category
newdata$m1a16 = factor(newdata$m1a16)

#m1b3 - relationship with father? Skip should be broken down into married and unknown
table(m1b3, m1a4)
newdata$m1b3[m1b3 == -6 & m1a4 == 1] = 0  #married couple
newdata$m1b3[m1b3 == -6 & m1a4 == 3] = 6  #father unkown
newdata$m1b3[m1b3 == -6 & m1a4 == 2] = -3  #unmarried but skipped section due to erroneous marker as unkown.  Value missing

newdata$m1b3[newdata$m1b3 %in% c(-9,-3,-1)] = NA  #make sure missing values don't become a category
newdata$m1b3 = factor(newdata$m1b3)



#########
#Merge parallel questions
#########
#m1b5x and m1b11x and m1b22x  (These three asked separately for those who are married or unmarried and are/ are not still involved with baby's father)
#need to combine values for those skipped on one question but responded in another section - so only updating -6's, not other values
newdata$m1b5a[m1b5a==-6]=m1b11a[m1b5a==-6]
newdata$m1b5a[m1b5a==-6 & m1b11a ==-6] = m1b22a[m1b5a==-6 & m1b11a ==-6]
newdata$m1b5b[m1b5b==-6]=m1b11b[m1b5b==-6]
newdata$m1b5b[m1b5b==-6 & m1b11b ==-6] = m1b22b[m1b5b==-6 & m1b11b ==-6]
newdata$m1b5c[m1b5c==-6]=m1b11c[m1b5c==-6]
newdata$m1b5c[m1b5c==-6 & m1b11c ==-6] = m1b22c[m1b5c==-6 & m1b11c ==-6]
newdata$m1b5d[m1b5d==-6]=m1b11d[m1b5d==-6]
newdata$m1b5d[m1b5d==-6 & m1b11d ==-6] = m1b22d[m1b5d==-6 & m1b11d ==-6]
drop = which(names(newdata) %in% c("m1b11a", "m1b22a", "m1b11b", "m1b22b", "m1b11c", "m1b22c", "m1b11d", "m1b22d"))
newdata = newdata[,-drop]

#m1b6x and m1b12x and m1b23x (These three asked separately for those who are married or unmarried and are/ are not still involved with baby's father)
newdata$m1b6a[m1b6a==-6]=m1b12a[m1b6a==-6]
newdata$m1b6a[m1b6a==-6 & m1b12a ==-6] = m1b23a[m1b6a==-6 & m1b12a ==-6]
newdata$m1b6b[m1b6b==-6]=m1b12b[m1b6b==-6]
newdata$m1b6b[m1b6b==-6 & m1b12b ==-6] = m1b23b[m1b6b==-6 & m1b12b ==-6]
newdata$m1b6c[m1b6c==-6]=m1b12c[m1b6c==-6]
newdata$m1b6c[m1b6c==-6 & m1b12c ==-6] = m1b23c[m1b6c==-6 & m1b12c ==-6]
newdata$m1b6d[m1b6d==-6]=m1b12d[m1b6d==-6]
newdata$m1b6d[m1b6d==-6 & m1b12d ==-6] = m1b23d[m1b6d==-6 & m1b12d ==-6]
newdata$m1b6e[m1b6e==-6]=m1b12e[m1b6e==-6]
newdata$m1b6e[m1b6e==-6 & m1b12e ==-6] = m1b23e[m1b6e==-6 & m1b12e ==-6]
newdata$m1b6f[m1b6f==-6]=m1b12f[m1b6f==-6]
newdata$m1b6f[m1b6f==-6 & m1b12f ==-6] = m1b23f[m1b6f==-6 & m1b12f ==-6]
drop = which(names(newdata) %in% c("m1b12a", "m1b23a", "m1b12b", "m1b23b", "m1b12c", "m1b23c", "m1b12d", "m1b23d", "m1b12e", "m1b23e", "m1b12f", "m1b23f"))
newdata = newdata[,-drop]

#m1b7x and m1b13x and m1b25x  (These three asked separately for those who are married or unmarried and are/ are not still involved with baby's father)
newdata$m1b7a[m1b7a==-6]=m1b13a[m1b7a==-6]
newdata$m1b7a[m1b7a==-6 & m1b13a ==-6] = m1b25a[m1b7a==-6 & m1b13a ==-6]
newdata$m1b7b[m1b7b==-6]=m1b13b[m1b7b==-6]
newdata$m1b7b[m1b7b==-6 & m1b13b ==-6] = m1b25b[m1b7b==-6 & m1b13b ==-6]
newdata$m1b7c[m1b7c==-6]=m1b13c[m1b7c==-6]
newdata$m1b7c[m1b7c==-6 & m1b13c ==-6] = m1b25c[m1b7c==-6 & m1b13c ==-6]
newdata$m1b7d[m1b7d==-6]=m1b13d[m1b7d==-6]
newdata$m1b7d[m1b7d==-6 & m1b13d ==-6] = m1b25d[m1b7d==-6 & m1b13d ==-6]
newdata$m1b7e[m1b7e==-6]=m1b13e[m1b7e==-6]
newdata$m1b7e[m1b7e==-6 & m1b13e ==-6] = m1b25e[m1b7e==-6 & m1b13e ==-6]
drop = which(names(newdata) %in% c("m1b13a", "m1b25a", "m1b13b", "m1b25b", "m1b13c", "m1b25c", "m1b13d", "m1b25d", "m1b13e", "m1b25e", "m1b13f", "m1b25f"))
newdata = newdata[,-drop]

#########
#Drop repeated vars
#########
drop = which(names(newdata) %in% c("m1a10", "m1b0", "m1b2"))
newdata = newdata[,-drop]

#########
#Run Rabia's code
source("./01_Cleaning/data_cleaning_BF_w1.R")
source("./01_Cleaning/data_cleaning_MB_w1.R")

#########
#Output cleaned data
#########
write.csv(newdata, file = outname, row.names = F)
var.classes = sapply(newdata, class)
save(var.classes, file = "../Data/Wave1_clean_class.RData")
