filename ="../Data/Wave4.csv"
outname ="../Data/Wave4_clean.csv"
data = read.csv(filename)
attach(data)


###########
#Remove variables we don't need to include
#(Some - mostly weights - already removed, but will not affect code if they are missing)
###########
drop = which(names(data) %in% c("idnum","mothid4","m4intmon","m4intyr","cm4twoc","cm4fint","cm4natsm","m4natwt",
                                "cm4natsmx","cm4citsm","m4a8", "f4a4c2","f4c37c1","f4c37e2",
                                "cf4citsm","cf4natsmx","cf4natsm","cf4twoc","f4lenmin","f4lenhr","f4intyr","f4intmon",
                                "fathid4", "cm4tdiff","f4a3b1b_3","f4a4d","f4b3b_5","f4c1a","f4f2d9","f4i16a_3","f4i28_5", "f4k26f_3","f4k26f_5","hv4a21c2_3", "hv4a21c3_2", "hv4a21c3_3",
                                "hv4a21c3_7", "hv4a21d1_3", "hv4a21d3_1", "hv4a21d3_4", "hv4a21d3_5", "hv4b21_3","hv4q4","kind_d5c","m4a3b1b_2",  "m4a8b_2", "m4b22a",  "m4b30a", 
                                "m4c21d_6","m4f3a2_6","m4k3a_11","m4k3a_6", "f4c37d2"))


newdata = data[,-drop]  #note that if you need to drop more, add them to the above, or replace names(data) with names(newdata), 
detach(data)
attach(newdata)


###########
#Section A - Mother Survey
###########
factorize <- function(vars,data,toSetNA = c(-9,-5,-3,-2,-1)) {
  for(i in vars){
    data[,i][data[,i] %in% toSetNA] = NA
    data[,i] = factor(data[,i])
  }
  data[,vars]
}

newdata$m4a3c[m4a3 == -10] = 0 #If never lived there, then 0 month lived there
newdata$m4a3g[m4a3 == -10] = 0 #Never lived = 0 days spent living with you?

newdata$m4a11a[m4a11b == 2] = -6 #If never been married, cannot answer 'were you ever married to...'
newdata$m4a11c[m4a11b == 2] = -6 #NA for number of times married
newdata$m4a12a1[m4a11b == 2] = -6 
newdata$m4a12a2a[m4a11b == 2] = -6
newdata$m4a12a2c[m4a11b == 2] = -6
newdata$m4a12a3a[m4a11b == 2] = -6 
newdata$m4a12a3c[m4a11b == 2] = -6
newdata$m4a12b1[m4a11b == 2] = -6 #Divorces can't happen without being married
newdata$m4a12b2[m4a11b == 2] = -6
newdata$m4a12b3[m4a11b == 2] = -6 

newdata$m4a16[m4a15 == 2] = 2 #If never pregnant, can't have abortion/miscarriage

newdata$m4b2c[m4b2b == 2] = 2 #The original skip logic seemed to have skipped this asmtha question if their answer was no to the doctor (some assumption). I don't think this should be right (nor it being 2)

newdata$m4k20[m4k4 == 2] = 1 #Less money earned from reg jobs if they didn't have one
newdata$m4k5[m4k4 == 1] = 3 #Create new variable if they have reg job. Could be or not looking even with reg job
newdata$m4k6[m4k5 == 2 | newdata$m4k5==3] = 0 #However much time they looking

newdata$m4j19[m4j18 == 2] = 0 #No packs smoked if they don't smoke
newdata$m4j20a[m4j20 == 0 | m4j20 == 1] = 0 #No time if don't drink within 12 months
newdata$m4j21[m4j18 == 0 | m4j20 == 1] = 2 #No drinking hangovers if dont drink
newdata$m4j21[m4j21 == 3] = 2

newdata$m4j2d[m4j2c == 2] = 0 #No times to hosipital if none state previously
newdata$m4j2d1[m4j2c == 2] = 0

#newdata$m4j22k[m4j22a == 1 | m4j22b == 1 | m4j22c == 1 | m4j22d == 1 |  m4j22e == 1 | m4j22f == 1 | m4j22g == 1 | m4j22h == 1 | m4j22i == 1 ] = 6 #Previously stated did a drug

newdata$m4k2_1[m4k1 == 2] = 2 #Did not attend if previously stated did not
newdata$m4k2_2[m4k1 == 2] = 2
newdata$m4k2_3[m4k1 == 2] = 2
newdata$m4k2_4[m4k1 == 2] = 2
newdata$m4k2_5[m4k1 == 2] = 2
newdata$m4k2_6[m4k1 == 2] = 2
newdata$m4k2_7[m4k1 == 2] = 2
newdata$m4k2_8[m4k1 == 2] = 2
newdata$m4k2_9[m4k1 == 2] = 2
newdata$m4k2_10[m4k1 == 2] = 2
newdata$m4k2_11[m4k1 == 2] = 2
newdata$m4k2_12[m4k1 == 2] = 2
newdata$m4k2_13[m4k1 == 2] = 2
newdata$m4k2_14[m4k1 == 2] = 2
newdata$m4k2_15[m4k1 == 2] = 2

newdata$m4k3a_1[m4k1 == 2] = 2 #Did not complete if previously stated did not
newdata$m4k3a_2[m4k1 == 2] = 2
newdata$m4k3a_3[m4k1 == 2] = 2
newdata$m4k3a_4[m4k1 == 2] = 2
newdata$m4k3a_5[m4k1 == 2] = 2
newdata$m4k3a_6[m4k1 == 2] = 2
newdata$m4k3a_7[m4k1 == 2] = 2
newdata$m4k3a_8[m4k1 == 2] = 2
newdata$m4k3a_9[m4k1 == 2] = 2
newdata$m4k3a_10[m4k1 == 2] = 2
newdata$m4k3a_11[m4k1 == 2] = 2
newdata$m4k3a_12[m4k1 == 2] = 2
newdata$m4k3a_13[m4k1 == 2] = 2
newdata$m4k3a_14[m4k1 == 2] = 2
newdata$m4k3a_15[m4k1 == 2] = 2
newdata$m4k3a_16[m4k1 == 2] = 2

#newdata$m4k3a_2a = factor(newdata$m4k3a_2a) #GED
#Recode for father unknown variables
newdata$m4a4e[m4a4 == -13] = 2

newdata$m4a9[m4a4 == -13] = -6 #NA for often seeing each other

newdata$m4a4a2[m4a4 %in% c(-13,3,4,5,6)] = 2 #Mother and father are not married or spending most time
newdata$m4a12e[m4a4 %in% c(-13,3,4,5,6)] = 2

newdata$m4b3b_2[m4a4 == -13] = 2 #Paternal Grandparent is 'no' if father is 'unknown'

newdata$m4c2[m4a4 == -13] = 2 #If father unknown, then cannot see child

newdata$m4c2c[m4a4==-13] = 2 #If father unknown, they cannot stay overnight

newdata$m4c4[m4a4 == -13] = 2 # Can't spank child if you missingno

newdata$m4c8[m4a4 == -13] = 2 #No marriage if unknown
newdata$m4c9[m4a4 == -13] = 2 #Paternity was not established if father is still unknown
newdata$m4c10a[m4a4 == -13] = 2 

newdata$m4c21[m4a4 == -13] = 2 #No paternity child support if unknown
newdata$m4c21c[m4a4 == -13] = 2

newdata$m4c28[m4a4 == -13] = 2 #Don't know about other children ith unknown father
newdata$m4c32[m4a4 == -13 | m4a10 == 1] = 2 #No other children to pay support for

newdata$m4c34[m4a4 == -14] = 2 #Father not living with other woman if dead
newdata$m4c34[m4a4 == -13] = -2


newdata$m4c36[m4a4 == -13] = -2 #Don't know the answers to these questions if father unknown
newdata$m4c37[m4a4 == -13] = -2
newdata$m4c37a_1[m4c37== 2] = 2
newdata$m4c37a_2[m4c37== 2] = 2
newdata$m4c37a_3[m4c37== 2] = 2
newdata$m4c37a_4[m4c37== 2] = 2
newdata$m4c37a_5[m4c37== 2] = 2
newdata$m4c37a_6[m4c37== 2] = 2
newdata$m4c37a_7[m4c37== 2] = 2
newdata$m4c37a_8[m4c37== 2] = 2

newdata$m4c38[m4a4 == -13] = -2
newdata$m4c39[m4a4 == -13] = -2


####Factor
newdata$m4a4[m4a4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4a4 = factor(newdata$m4a4)

newdata$m4a9[m4a9 %in% c(-9, -3, -2, -1)] = NA
newdata$m4a9 = factor(newdata$m4a9)

newdata$m4f1[m4f1 %in% c(-9, -2, -1)] = NA
newdata$m4f1= factor(newdata$m4f1)

newdata$m4a13[m4a13 %in% c(-9, -3, -2, -1)] = NA
newdata$m4a13 = factor(newdata$m4a13)

newdata$m4a14[m4a14 %in% c(-9, -2)] = NA
newdata$m4a14 = factor(newdata$m4a14)

newdata$m4c2[m4c2 %in% c(-9, -2)] = NA
newdata$m4c2 = factor(newdata$m4c2)

newdata$m4c2f[m4c2f %in% c(-9, -6, -2, -1)] = NA
newdata$m4c2f = factor(newdata$m4c2f)

newdata$m4c5[m4c5 %in% c(-9, -6, -2)] = NA
newdata$m4c5 = factor(newdata$m4c5)

newdata$m4c5b[m4c5b %in% c(-9,-6, -2, -1)] = NA
newdata$m4c5b = factor(newdata$m4c5b)

newdata$m4c6[m4c6 %in% c(-9, -6)] = NA
newdata$m4c6 = factor(newdata$m4c6)

newdata$m4c10a1[m4c10a1 %in% c(-9, -6, -2, -1)] = NA
newdata$m4c10a1 = factor(newdata$m4c10a1)

newdata$m4c13[m4c13 %in% c(-9, -2, -1)] = NA
newdata$m4c13 = factor(newdata$m4c13)

newdata$m4c13a1[m4c13a1 %in% c(-9, -2, -1)] = NA
newdata$m4c13a1 = factor(newdata$m4c13a1)

newdata$m4c13a3[m4c13a3 %in% c(-9, -2, -1)] = NA
newdata$m4c13a3 = factor(newdata$m4c13a3)

newdata$m4c14a = factor(newdata$m4c14a)
newdata$m4c15 = factor(newdata$m4c15)

newdata$m4c18[m4c18 %in% c(-2, -1)] = NA
newdata$m4c18 = factor(newdata$m4c18)

newdata$m4c19[m4c19 %in% c(-2, -1)] = NA
newdata$m4c19 = factor(newdata$m4c19)

newdata$m4c20[m4c20 %in% c(-2, -1)] = NA
newdata$m4c20 = factor(newdata$m4c20)

newdata$m4c20a[m4c20a %in% c(-5, -2, -1)] = NA
newdata$m4c20a = factor(newdata$m4c20a)

newdata$m4c20b[m4c20b == -2] = NA
newdata$m4c20b = factor(newdata$m4c20b)

newdata$m4c20d[m4c20d %in% c(-2, -1)] = NA
newdata$m4c20d = factor(newdata$m4c20d)

newdata$m4c21[m4c21 %in% c(-2, -1)] = NA
newdata$m4c21 = factor(newdata$m4c21)

newdata$m4c21c[m4c21c == -2] = NA
newdata$m4c21c = factor(newdata$m4c21c)

newdata$m4c22a[m4c22a %in% c(-2, -1)] = NA
newdata$m4c22a = factor(newdata$m4c22a)

newdata$m4c25[m4c25 %in% c(-5, -2, -1)] = NA
newdata$m4c25 = factor(newdata$m4c25)

newdata$m4c26a[m4c26a %in% c(-9, -5, -2, -1)] = NA
newdata$m4c26a = factor(newdata$m4c26a)
newdata$m4c26b[m4c26b %in% c(-9, -5, -2, -1)] = NA
newdata$m4c26b = factor(newdata$m4c26b)
newdata$m4c26c[m4c26c %in% c(-9, -5, -2, -1)] = NA
newdata$m4c26c = factor(newdata$m4c26c)
newdata$m4c26d[m4c26d %in% c(-9, -5, -2, -1)] = NA
newdata$m4c26d = factor(newdata$m4c26d)
newdata$m4c26e[m4c26e %in% c(-9, -5, -2, -1)] = NA
newdata$m4c26e = factor(newdata$m4c26e)

newdata$m4c31a[m4c31a %in% c(-9, -5, -2, -1)] = NA
newdata$m4c31a = factor(newdata$m4c31a)
newdata$m4c32[m4c32 %in% c(-9, -5, -2, -1)] = NA
newdata$m4c32 = factor(newdata$m4c32)

newdata$m4c34[m4c34 %in% c(-9, -5, -2, -1)] = NA
newdata$m4c34 = factor(newdata$m4c34)

newdata$m4c35b[m4c35b %in% c(-9, -5, -2, -1)] = NA
newdata$m4c35b = factor(newdata$m4c35b)

newdata$m4c36[m4c36 %in% c(-9, -5, -6, -2, -1)] = NA
newdata$m4c36 =factor(newdata$m4c36)
newdata$m4c37[m4c37 %in% c(-9, -5, -6, -2, -1)] = NA
newdata$m4c37 = factor(newdata$m4c37)
#newdata$m4c37a_1[m4c37a_1 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_1 = factor(newdata$m4c37a_1)
#newdata$m4c37a_2[m4c37a_2 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_2 = factor(newdata$m4c37a_2)
#newdata$m4c37a_3[m4c37a_3 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_3 = factor(newdata$m4c37a_3)
#newdata$m4c37a_4[m4c37a_4 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_4 = factor(newdata$m4c37a_4)
#newdata$m4c37a_5[m4c37a_5 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_5 = factor(newdata$m4c37a_5)
#newdata$m4c37a_6[m4c37a_6 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_6 = factor(newdata$m4c37a_6)
#newdata$m4c37a_7[m4c37a_7 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_7 = factor(newdata$m4c37a_7)
#newdata$m4c37a_8[m4c37a_8 %in% c(-6, -2, -1)] = NA
#newdata$m4c37a_8 = factor(newdata$m4c37a_8)

newdata$m4d4[m4d4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4d4 = factor(newdata$m4d4)

newdata$m4d1[m4d1 %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1 = factor(newdata$m4d1)
newdata$m4d1a[m4d1a %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1a = factor(newdata$m4d1a)
newdata$m4d1b[m4d1b %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1b = factor(newdata$m4d1b)
newdata$m4d1c[m4d1c %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1c = factor(newdata$m4d1c)
newdata$m4d1d[m4d1d %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1d = factor(newdata$m4d1d)
newdata$m4d1e[m4d1e %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1e = factor(newdata$m4d1e)
newdata$m4d1f[m4d1f %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1f = factor(newdata$m4d1f)
newdata$m4d1f[m4d1f %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1f = factor(newdata$m4d1f)
newdata$m4d1g[m4d1g %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1g = factor(newdata$m4d1g)
newdata$m4d1h[m4d1h %in% c(-9, -3, -2, -1)] = NA
newdata$m4d1h = factor(newdata$m4d1h)

newdata$m4d2[m4d2 %in% c(-9, -3, -2, -1)] = NA
newdata$m4d2 = factor(newdata$m4d2)
newdata$m4d3[m4d3 %in% c(-9, -3, -2, -1)] = NA
newdata$m4d3 = factor(newdata$m4d3)

newdata$m4d4[m4d4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4d4 = factor(newdata$m4d4)
newdata$m4d4a[m4d4a %in% c(-9, -3, -2, -1)] = NA
newdata$m4d4a = factor(newdata$m4d4a)

newdata$m4e25[m4e25 %in% c(-9, -3, -2, -1)] = NA
newdata$m4e25 = factor(newdata$m4e25)

newdata[,names(newdata)[startsWith(names(newdata),"m4h1")]] = factorize(names(newdata)[startsWith(names(newdata),"m4h1")],newdata)

newdata$m4i1a[m4i1 == 2] = 0
newdata$m4i2[m4i2 %in% c(-9, -3, -2, -1)] = NA
newdata$m4i2 = factor(newdata$m4i2)
newdata$m4i4b[m4i4b %in% c(-9, -3, -2, -1)] = NA
newdata$m4i4b = factor(newdata$m4i4b)
newdata$m4i5[m4i5 %in% c(-9, -3, -2, -1)] = NA
newdata$m4i5 = factor(newdata$m4i5)
newdata$m4i6[m4i6 %in% c(-9, -3, -2, -1)] = NA
newdata$m4i6 = factor(newdata$m4i6)
newdata$m4i7f[m4i7f %in% c(-9, -3, -2, -1)] = NA

newdata$m4k5[m4k4 == 1] = 2
newdata$m4k6[m4k6 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k6 = factor(newdata$m4k6)
newdata$m4k7[m4k7 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k7 = factor(newdata$m4k7)
newdata$m4k11[m4k11 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k11 = factor(newdata$m4k11)
newdata$m4k14a1[m4k14a1 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14a1 = factor(newdata$m4k14a1)
newdata$m4k14a2[m4k14a2 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14a2 = factor(newdata$m4k14a2)
newdata$m4k14a3[m4k14a3 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14a3 = factor(newdata$m4k14a3)
newdata$m4k14a4[m4k14a4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14a4 = factor(newdata$m4k14a4)
newdata$m4k14a5[m4k14a5 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14a5 = factor(newdata$m4k14a5)
newdata$m4k14b1[m4k14b1 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14b1 = factor(newdata$m4k14b1)
newdata$m4k14b2[m4k14b2 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14b2 = factor(newdata$m4k14b2)
newdata$m4k14b3[m4k14b3 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14b3 = factor(newdata$m4k14b3)
newdata$m4k14b4[m4k14b4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4k14b4 = factor(newdata$m4k14b4)
newdata$m4k16a[m4k16a %in% c(-9, -3, -2, -1)] = NA
newdata$m4k16a = factor(newdata$m4k16a)
newdata$m4k16b[m4k16b %in% c(-9, -3, -2, -1)] = NA
newdata$m4k16b = factor(newdata$m4k16b)
newdata$m4k16c[m4k16c %in% c(-9, -3, -2, -1)] = NA
newdata$m4k16c = factor(newdata$m4k16c)
newdata$m4k22[m4k22 == -6] = 0
newdata$m4k24b[m4k24a == 2] = 0
newdata$m4k24c[m4k24b == 2] = 0
newdata$m4k24d[m4k24d %in% c(-9, -3, -2, -1)] = NA
newdata$m4k24d = factor(newdata$m4k24d)
newdata$m4k24e[m4k24a == 2] = 0
newdata$m4k26b[m4k26a == 2] = 0
newdata$m4k26c[m4k26a == 2] = 0
newdata$m4k26d[m4k26d %in% c(-9, -3, -2, -1)] = NA
newdata$m4k26d = factor(newdata$m4k26d)
newdata$m4k26e[m4k26a == 2] = 0

newdata$m4l1[m4l1 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l1 = factor(newdata$m4l1)
newdata$m4l4[m4l4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l4 = factor(newdata$m4l4)
newdata$m4l4a[m4l4a %in% c(-9, -3, -2, -1)] = NA
newdata$m4l4a = factor(newdata$m4l4a)
newdata$m4l5[m4l5 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l5 = factor(newdata$m4l5)
newdata$m4l5a[m4l5a %in% c(-9, -3, -2, -1)] = NA
newdata$m4l5a = factor(newdata$m4l5a)
newdata$m4l5b[m4l5b %in% c(-9, -3, -2, -1)] = NA
newdata$m4l5b = factor(newdata$m4l5b)
newdata$m4l5c[m4l5c %in% c(-9, -3, -2, -1)] = NA
newdata$m4l5c = factor(newdata$m4l5c)
newdata$m4l5d[m4l5d %in% c(-9, -3, -2, -1)] = NA
newdata$m4l5d = factor(newdata$m4l5d)
newdata$m4l6[m4l6 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l6 = factor(newdata$m4l6)
newdata$m4l6a[m4l6==2] = 2
newdata$m4l7[m4l7 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l7 = factor(newdata$m4l7)
newdata$m4l8[m4l8 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l8 = factor(newdata$m4l8)
newdata$m4l9a[m4l9 == 2] = 2
newdata$m4l9[m4l9 %in% c(-9, -3, -2, -1)] = NA
newdata$m4l9 = factor(newdata$m4l9)
newdata$m4l9a[m4l9a %in% c(-9, -3, -2, -1)] = NA
newdata$m4l9a = factor(newdata$m4l9a)

newdata$m4c21d_1[m4c21d_1 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_1 = factor(newdata$m4c21d_1)
newdata$m4c21d_2[m4c21d_2 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_2 = factor(newdata$m4c21d_2)
newdata$m4c21d_3[m4c21d_3 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_3 = factor(newdata$m4c21d_3)
newdata$m4c21d_4[m4c21d_4 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_4 = factor(newdata$m4c21d_4)
newdata$m4c21d_5[m4c21d_5 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_5 = factor(newdata$m4c21d_5)
#newdata$m4c21d_6[m4c21d_6 %in% c(-9, -3, -2, -1)] = NA
#newdata$m4c21d_6 = factor(newdata$m4c21d_6)
newdata$m4c21d_7[m4c21d_7 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_7 = factor(newdata$m4c21d_7)
newdata$m4c21d_8[m4c21d_8 %in% c(-9, -3, -2, -1)] = NA
newdata$m4c21d_8 = factor(newdata$m4c21d_8)

newdata$cm4povca[cm4povca %in% c(-9, -6, -3, -2, -1)] = NA
newdata$cm4povca = factor(newdata$cm4povca)
newdata$cm4relf[cm4relf %in% c(-9, -6, -3, -2, -1)] = NA
newdata$cm4relf = factor(newdata$cm4relf)

#########
#Section B - Father's Survey
#########
newdata$cf4povca[cf4povca %in% c(-9, -6, -3, -2, -1)] = NA
newdata$cf4povca = factor(newdata$cf4povca)

newdata$f4a4[f4a4 == -6] = -14
newdata$f4a9[f4a4 == 1 | f4a4a1 == 1] =6

newdata$f4a2[f4a2 %in% c(-9, -3, -2, -1)] = NA
newdata$f4a2 = factor(newdata$f4a2)
newdata$f4a4[f4a4 %in% c(-9, -3, -2, -1)] = NA
newdata$f4a4 = factor(newdata$f4a4)
newdata$f4a9[f4a9 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4a9 = factor(newdata$f4a9)
newdata$f4f1[f4f1 %in% c(-9, -3, -2, -1)] = NA
newdata$f4f1 = factor(newdata$f4f1)
newdata$f4e13[f4e13 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e13 = factor(newdata$f4e13)
newdata$f4a13a[f4a13a %in% c(-9, -3, -2, -1)] = NA
newdata$f4a13a = factor(newdata$f4a13a)
newdata$f4a14[f4a14 %in% c(-9, -3, -2, -1)] = NA
newdata$f4a14 = factor(newdata$f4a14)

newdata$f4c5[f4c5 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c5 = factor(newdata$f4c5)
newdata$f4c5b[f4c5b %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4c5b = factor(newdata$f4c5b)
newdata$f4c6[f4c6 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c6 = factor(newdata$f4c6)
newdata$f4c6a[f4c6a %in% c(-9, -3, -2, -1)] = NA
newdata$f4c6a = factor(newdata$f4c6a)
newdata$f4c13[f4c13 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c13 = factor(newdata$f4c13)
newdata$f4c20b[f4c20b %in% c(-9, -3, -2, -1)] = NA
newdata$f4c20b = factor(newdata$f4c20b)
newdata$f4c21[f4c21 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c21 = factor(newdata$f4c21)
newdata$f4c22a[f4c22a %in% c(-9, -3, -2, -1)] = NA
newdata$f4c22a = factor(newdata$f4c22a)
newdata$f4c25[f4c25 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c25 = factor(newdata$f4c25)

newdata$f4c26a[f4c26a %in% c(-9, -3, -2, -1)] = NA
newdata$f4c26a = factor(newdata$f4c26a)
newdata$f4c26b[f4c26b %in% c(-9, -3, -2, -1)] = NA
newdata$f4c26b = factor(newdata$f4c26b)
newdata$f4c26c[f4c26c %in% c(-9, -3, -2, -1)] = NA
newdata$f4c26c = factor(newdata$f4c26c)
newdata$f4c26d[f4c26d %in% c(-9, -3, -2, -1)] = NA
newdata$f4c26d = factor(newdata$f4c26d)
newdata$f4c26e[f4c26e %in% c(-9, -3, -2, -1)] = NA
newdata$f4c26e = factor(newdata$f4c26e)

newdata$f4c28[f4c28 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c28 = factor(newdata$f4c28)

newdata$f4d4[f4d4 %in% c(-9, -3, -2, -1)] = NA
newdata$f4d4 = factor(newdata$f4d4)
#newdata$f4d6a[f4d6a %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6a = factor(newdata$f4d6a)
#newdata$f4d6b[f4d6b %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6b = factor(newdata$f4d6b)
#newdata$f4d6c[f4d6c %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6c = factor(newdata$f4d6c)
#newdata$f4d6d[f4d6d %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6d = factor(newdata$f4d6d)
#newdata$f4d6e[f4d6e %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6e = factor(newdata$f4d6e)
#newdata$f4d6f[f4d6f %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6f = factor(newdata$f4d6f)
#newdata$f4d6g[f4d6g %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6g = factor(newdata$f4d6g)
#newdata$f4d6h[f4d6h %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6h = factor(newdata$f4d6h)
#newdata$f4d6i[f4d6i %in% c(-9, -6, -3, -2, -1)] = NA
#newdata$f4d6i = factor(newdata$f4d6i)

newdata$f4d1a[f4d1a %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1a = factor(newdata$f4d1a)
newdata$f4d1b[f4d1b %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1b = factor(newdata$f4d1b)
newdata$f4d1c[f4d1c %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1c = factor(newdata$f4d1c)
newdata$f4d1d[f4d1d %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1d = factor(newdata$f4d1d)
newdata$f4d1e[f4d1e %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1e = factor(newdata$f4d1e)
newdata$f4d1f[f4d1f %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1f = factor(newdata$f4d1f)
newdata$f4d1g[f4d1g %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1g = factor(newdata$f4d1g)
newdata$f4d1h[f4d1h %in% c(-9, -3, -2, -1)] = NA
newdata$f4d1h = factor(newdata$f4d1h)

newdata$f4e5[f4e5 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e5 = factor(newdata$f4e5)
newdata$f4e5a[f4e5a %in% c(-9, -3, -2, -1)] = NA
newdata$f4e5a = factor(newdata$f4e5a)
newdata$f4e5b[f4e5a ==2] = 0
newdata$f4e5b[f4e5b %in% c(-9, -3, -2, -1)] = NA
newdata$f4e5b = factor(newdata$f4e5b)
newdata$f4e6[f4e6 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e6 = factor(newdata$f4e6)
newdata$f4e7[f4e7 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e7 = factor(newdata$f4e7)
newdata$f4e8[f4e8 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e8 = factor(newdata$f4e8)
newdata$f4e9[f4e9 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e9 = factor(newdata$f4e9)
newdata$f4e10[f4e10 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e10 = factor(newdata$f4e10)
newdata$f4e11a[f4e11 == 2] = 0
newdata$f4e11a[f4e11a == -6] = 0
newdata$f4e11b[f4e11 == 2] = 0
newdata$f4e11b[f4e11b == -6] = 0
newdata$f4e11[f4e11 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e11 = factor(newdata$f4e11)
newdata$f4e15[f4e15 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e15 = factor(newdata$f4e15)
newdata$f4e13[f4e13 %in% c(-9, -3, -2, -1)] = NA
newdata$f4e13 = factor(newdata$f4e13)
#newdata$f4d10[f4d10 %in% c(-9, -3, -2, -1)] = NA
#newdata$f4d10 = factor(newdata$f4d10)
#newdata$f4d10a[f4d10a %in% c(-9, -3, -2, -1)] = NA
#newdata$f4d10a = factor(newdata$f4d10a)
newdata$f4c37[f4c37 %in% c(-9, -3, -2, -1)] = NA
newdata$f4c37 = factor(newdata$f4c37)

newdata$f4h1g[f4h1g %in% c(-9, -3, -2, -1)] = NA
newdata$f4h1g = factor(newdata$f4h1g)
newdata$f4h1h[f4h1g %in% c(2,3,4)] = 0
newdata$f4h1h[f4h1h %in% c(-9, -3, -2, -1)] = NA
newdata$f4h1h = factor(newdata$f4h1h)
newdata$f4h1i[f4h1i %in% c(-9, -3, -2, -1)] = NA
newdata$f4h1i = factor(newdata$f4h1i)
newdata$f4h1k[f4h1k %in% c(-9, -3, -2, -1)] = NA
newdata$f4h1k = factor(newdata$f4h1k)
newdata$f4h1l[f4h1l %in% c(-9, -3, -2, -1)] = NA
newdata$f4h1l = factor(newdata$f4h1l)

newdata$f4h2c[f4h2 == 2] = 0
newdata$f4h3a[f4h3 == 2] = 2
newdata$f4h6a[f4h6 == 2] = 2
newdata$f4i0j[f4i0j == 0] = -3

newdata$f4i1a[f4i1 == 2] = 0
newdata$f4i2[f4i2 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i2 = factor(newdata$f4i2)
newdata$f4i4b[f4i4b %in% c(-9, -3, -2, -1)] = NA
newdata$f4i4b = factor(newdata$f4i4b)
newdata$f4i5[f4i5 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i5 = factor(newdata$f4i5)
newdata$f4i6[f4i6 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i6 = factor(newdata$f4i6)
newdata$f4i7f[f4i7e == 2] = -3

newdata$f4i8b1[f4i8a1 == 2] = 0
newdata$f4i8c1[f4i8a1 == 2] = 0
newdata$f4i8b2[f4i8a2 == 2] = 0
newdata$f4i8c2[f4i8a2 == 2] = 0
newdata$f4i8b3[f4i8a3 == 2] = 0
newdata$f4i8c3[f4i8a3 == 2] = 0
newdata$f4i10[f4i10 == -6] = 2
newdata$f4i11a[f4i10 == -6] = 0
newdata$f4i12[f4i12 == -6] = 1
newdata$f4i14[f4i14 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i14 = factor(newdata$f4i14)
newdata$f4i14a[f4i14a %in% c(-9, -3, -2, -1)] = NA
newdata$f4i14a = factor(newdata$f4i14a)
newdata$f4i14b[f4i14b %in% c(-9, -3, -2, -1)] = NA
newdata$f4i14b = factor(newdata$f4i14b)
newdata$f4i16[f4i16 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i16 = factor(newdata$f4i16)
newdata$f4i17[f4i17 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i17 = factor(newdata$f4i17)
newdata$f4i18[f4i18 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i18 = factor(newdata$f4i18)
newdata$f4i18a[f4i18a %in% c(-9, -3, -2, -1)] = NA
newdata$f4i18a = factor(newdata$f4i18a)
newdata$f4i18b[f4i18b %in% c(-9, -3, -2, -1)] = NA
newdata$f4i18b = factor(newdata$f4i18b)
newdata$f4i18c[f4i18c %in% c(-9, -3, -2, -1)] = NA
newdata$f4i18c = factor(newdata$f4i18c)
newdata$f4i18d[f4i18d %in% c(-9, -3, -2, -1)] = NA
newdata$f4i18d = factor(newdata$f4i18d)
newdata$f4i18e[f4i18e %in% c(-9, -3, -2, -1)] = NA
newdata$f4i18e = factor(newdata$f4i18e)
newdata$f4i18f[f4i18d == 2] = 0
newdata$f4i18g[f4i18d == 2] = 0
newdata$f4i20[f4i20 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i20 = factor(newdata$f4i20)
newdata$f4i20a[f4i20a %in% c(-9, -3, -2, -1)] = NA
newdata$f4i20a = factor(newdata$f4i20a)
newdata$f4i20b[f4i20b %in% c(-9, -3, -2, -1)] = NA
newdata$f4i20b = factor(newdata$f4i20b)
newdata$f4i21[f4i21 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i21 = factor(newdata$f4i21)
newdata$f4i22[f4i22 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i22 = factor(newdata$f4i22)
newdata$f4i23o[f4i23n == 2] = 0
newdata$f4i26[f4i25 == 2] = 2
newdata$f4i26a[f4i26 == 2] = 0
newdata$f4i27[f4i25 == 2] = 2
newdata$f4i27a[f4i27 == 2] = 0
newdata$f4i29[f4i29 %in% c(-9, -3, -2, -1)] = NA
newdata$f4i29 = factor(newdata$f4i29)


newdata$f4j0[f4j0 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4j0 = factor(newdata$f4j0)
newdata$f4j1[f4j1 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4j1 = factor(newdata$f4j1)

newdata$f4j19[f4j18 == 2] = 0 #Nothing smoked
newdata$f4j20a[f4j20 %in% c(0,1)] = 0
newdata$f4j21[f4j20 %in% c(0,1)] = 2

newdata$f4j19[f4j19 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4j19 = factor(newdata$f4j19)
newdata$f4j20[f4j20 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4j20 = factor(newdata$f4j20)
newdata$f4j20a[f4j20a %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4j20a = factor(newdata$f4j20a)

newdata$f4r1[f4r1 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4r1 = factor(newdata$f4r1)
newdata$f4r2[f4r2 %in% c(-9, -6, -3, -2, -1)] = NA
newdata$f4r2 = factor(newdata$f4r2)

newdata$f4k2_1[f4k1 == 2]=0
newdata$f4k2_2[f4k1 == 2]=0
newdata$f4k2_3[f4k1 == 2]=0
newdata$f4k2_4[f4k1 == 2]=0
newdata$f4k2_5[f4k1 == 2]=0
newdata$f4k2_6[f4k1 == 2]=0
newdata$f4k2_7[f4k1 == 2]=0
newdata$f4k2_8[f4k1 == 2]=0
newdata$f4k2_9[f4k1 == 2]=0
newdata$f4k2_10[f4k1 == 2]=0
newdata$f4k2_11[f4k1 == 2]=0
newdata$f4k2_12[f4k1 == 2]=0
newdata$f4k2_13[f4k1 == 2]=0
newdata$f4k2_14[f4k1 == 2]=0
newdata$f4k2_15[f4k1 == 2]=0
#newdata$f4k2_2a[f4k2_2a %in% c(-9, -3, -2, -1)] = NA
#newdata$f4k2_2a = factor(newdata$f4k2_2a)

newdata$f4k3_1[f4k3 == 2]=2
newdata$f4k3_2[f4k3 == 2]=2
newdata$f4k3_3[f4k3 == 2]=2
newdata$f4k3_4[f4k3 == 2]=2
newdata$f4k3_5[f4k3 == 2]=2
newdata$f4k3_6[f4k3 == 2]=2
newdata$f4k3_7[f4k3 == 2]=2
newdata$f4k3_8[f4k3 == 2]=2
newdata$f4k3_9[f4k3 == 2]=2
newdata$f4k3_10[f4k3 == 2]=2
newdata$f4k3_11[f4k3 == 2]=2
newdata$f4k3_12[f4k3 == 2]=2
newdata$f4k3_13[f4k3 == 2]=2
newdata$f4k3_14[f4k3 == 2]=2
newdata$f4k3_15[f4k3 == 2]=2
newdata$f4k3_15[f4k3 == 2]=2
newdata$f4k3_16[f4k3 == 2]=2
#newdata$f4k3a_2a[f4k3a_2a %in% c(-9, -3, -2, -1)] = NA
#newdata$f4k3a_2a = factor(newdata$f4k3a_2a)

newdata$f4k5[f4k4 == 1] = 2
newdata$f4k6[f4k6 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k6 = factor(newdata$f4k6)
newdata$f4k7[f4k7 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k7 = factor(newdata$f4k7)
newdata$f4k11[f4k11 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k11 = factor(newdata$f4k11)
newdata$f4k14a1[f4k14a1 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14a1 = factor(newdata$f4k14a1)
newdata$f4k14a2[f4k14a2 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14a2 = factor(newdata$f4k14a2)
newdata$f4k14a3[f4k14a3 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14a3 = factor(newdata$f4k14a3)
newdata$f4k14a4[f4k14a4 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14a4 = factor(newdata$f4k14a4)
newdata$f4k14a5[f4k14a5 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14a5 = factor(newdata$f4k14a5)
newdata$f4k14b1[f4k14b1 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14b1 = factor(newdata$f4k14b1)
newdata$f4k14b2[f4k14b2 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14b2 = factor(newdata$f4k14b2)
newdata$f4k14b3[f4k14b3 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14b3 = factor(newdata$f4k14b3)
newdata$f4k14b4[f4k14b4 %in% c(-9, -3, -2, -1)] = NA
newdata$f4k14b4 = factor(newdata$f4k14b4)
newdata$f4k16a[f4k16a %in% c(-9, -3, -2, -1)] = NA
newdata$f4k16a = factor(newdata$f4k16a)
newdata$f4k16b[f4k16b %in% c(-9, -3, -2, -1)] = NA
newdata$f4k16b = factor(newdata$f4k16b)
newdata$f4k16c[f4k16c %in% c(-9, -3, -2, -1)] = NA
newdata$f4k16c = factor(newdata$f4k16c)
newdata$f4k21[f4k21 == -6] = 0
newdata$f4k22[f4k22 == -6] = 0
newdata$f4k24b[f4k24a == 2] = 0
newdata$f4k24c[f4k24a == 2] = 0
newdata$f4k24d[f4k24d %in% c(-9, -3, -2, -1)] = NA
newdata$f4k24d = factor(newdata$f4k24d)
newdata$f4k24e[f4k24a == 2] = 0
newdata$f4k26b[f4k26a == 2] = 0
newdata$f4k26c[f4k26a == 2] = 0
newdata$f4k26d[f4k26d %in% c(-9, -3, -2, -1)] = NA
newdata$f4k26d = factor(newdata$f4k26d)
newdata$f4k26e[f4k26a == 2] = 0

newdata$f4l1a[f4l1a %in% c(-9, -3, -2, -1)] = NA
newdata$f4l1a = factor(newdata$f4l1a)
newdata$f4l4[f4l4 %in% c(-9, -3, -2, -1)] = NA
newdata$f4l4 = factor(newdata$f4l4)
newdata$f4l4a[f4l4a %in% c(-9, -3, -2, -1)] = NA
newdata$f4l4a = factor(newdata$f4l4a)
newdata$f4l5[f4l5 %in% c(-9, -3, -2, -1)] = NA
newdata$f4l5 = factor(newdata$f4l5)
newdata$f4l5a[f4l5a %in% c(-9, -3, -2, -1)] = NA
newdata$f4l5a = factor(newdata$f4l5a)
newdata$f4l5b[f4l5b %in% c(-9, -3, -2, -1)] = NA
newdata$f4l5b = factor(newdata$f4l5b)
newdata$f4l5c[f4l5c %in% c(-9, -3, -2, -1)] = NA
newdata$f4l5c = factor(newdata$f4l5c)
newdata$f4l5d[f4l5d %in% c(-9, -3, -2, -1)] = NA
newdata$f4l5d = factor(newdata$f4l5d)
newdata$f4l6[f4l6 %in% c(-9, -3, -2, -1)] = NA
newdata$f4l6 = factor(newdata$f4l6)
newdata$f4l6a[f4l6==2] = 2
newdata$f4l7[f4l7 %in% c(-9, -3, -2, -1)] = NA
newdata$f4l7 = factor(newdata$f4l7)
newdata$f4l8[f4l8 %in% c(-9, -3, -2, -1)] = NA
newdata$f4l8 = factor(newdata$f4l8)
newdata$f4l9a[f4l9 == 2] = 2
newdata$f4l9[f4l9 %in% c(-9, -3, -2, -1)] = NA
newdata$f4l9 = factor(newdata$f4l9)
newdata$f4l9a[f4l9a %in% c(-9, -3, -2, -1)] = NA
newdata$f4l9a = factor(newdata$f4l9a)


newdata$f4a3e[f4a2 == 4] = 0 #Does not see child


newdata$f4e15[f4e11==2]=2 #no biological children

newdata$f4c2c[f4c2 == 2] = 2
newdata$f4c2c[f4a4 == 1 | f4a4a1 == 1] = 1 #See child if married or living together
newdata$f4c2d[f4c2a == 2] = 0
newdata$f4c2d[f4a4 == 1 | f4a4a1 == 1] = 360
newdata$f4c2d1[f4a4 == 1 | f4a4a1 == 1] = 4 # If cohabiting, mother should see child many nights

newdata[f4h2 == 2, startsWith(names(newdata),"f4h2a")] = 2 #All these giving help questions is a no if they answered no previously
newdata$f4h2b[f4h2 == 2] = 0
newdata$f4h2c[f4h2 == 2] = 0

newdata[f4j2 == 2, startsWith(names(newdata), "f4j2a")] = 2 #No serious health problems > none of these
newdata[f4j2b == 2, startsWith(names(newdata),"f4j2b1")] = 2

newdata$f4j2d[f4j2c == 2] = 0 #No times stayed overnight at hospital
newdata$f4j2d1[f4j2c == 2] = 0



newdata[f4i8a1 == 2, startsWith(names(newdata),"f4i11")] = 0 #Not receiving TANF

newdata$f4i26[f4i25 == 2] = 2 #No charges pending
newdata$f4i26a[f4i25 == 2] = 0
newdata[f4i25 == 2, startsWith(names(newdata),"f4i26b")] = 2

#########
#Section C - Kindergarten Survey
#########
KindFactorVars = names(newdata)[grep("^kind",names(newdata))]
KindFactorVars = KindFactorVars[-(which(KindFactorVars %in% c("kind_a10","kind_d7","kind_e2a","kind_e2b","kind_e2c","kind_e2d")))]

for(i in KindFactorVars){
  newdata[which(newdata[,i] %in% c(-9,-3,-2,-1)),i] = NA
}

for(i in c("kind_a10","kind_e2a","kind_e2b","kind_e2c","kind_e2d")){
  newdata[which(newdata[,i] %in% c(-9,-3,-2,-1,6)),i] = NA
}


###########
#Home visit questionnaire
###########
newdata$hv4a1 = factor(hv4a1)
newdata$hv4a5[hv4a4 == 0] = 0
newdata$hv4a5 = factor(newdata$hv4a5)
newdata$hv4a6 = factor(hv4a6)
newdata$hv4a8 = factor(hv4a8)
newdata$hv4a10 = factor(hv4a10)
newdata$hv4a11 = factor(hv4a11)
newdata$hv4a13[hv4a12 == 0] = 0
newdata$hv4a15[hv4a14 == 0] = 0
newdata$hv4a17[hv4a16 == 0] = 0
newdata$hv4a18[hv4a16 == 0] = 0
newdata$hv4a19[hv4a16 == 0] = 0
newdata$hv4a21b1[hv4a20 == 0] = 0
newdata$hv4a21b1 = factor(newdata$hv4a21b1)
newdata$hv4a21c1_0[hv4a20 == 0] = 0
newdata$hv4a21b2[hv4a21e1 == 0 | hv4a20 == 0] = 0
newdata$hv4a21b2 = factor(newdata$hv4a21b2)
newdata$hv4a21c2_5[hv4a21e1 == 0 | hv4a20 == 0] = 0
newdata$hv4a21c2_8[hv4a21e1 == 0 | hv4a20 == 0] = 0
newdata$hv4a21c2_0[hv4a21e1 == 0 | hv4a20 == 0] = 0
newdata$hv4a21b3[hv4a21e1 == 0 |hv4a21e2 == 0 | hv4a20 == 0] = 0
newdata$hv4a21b3 = factor(newdata$hv4a21b3)
newdata$hv4a21c3_0[hv4a21e1 == 0 |hv4a21e2 == 0 | hv4a20 == 0] = 0
newdata$hv4a23[hv4a22 == 0] = 0
newdata$hv4a24[hv4a22 == 0] = 0
newdata$hv4a25 = factor(hv4a25)
newdata$hv4a26 = factor(hv4a26)
newdata$hv4a27 = factor(hv4a27)
newdata$hv4a30 = factor(hv4a30)

newdata$hv4b8[hv4b7 == 0] = 0
newdata$hv4b10[hv4b9 == 0] = 0
newdata$hv4b12hr[!is.na(hv4b12hr)] = hv4b12hr[!is.na(hv4b12hr)] + hv4b12min[!is.na(hv4b12hr)]/60 + hv4b12ampm[!is.na(hv4b12hr)]*12
newdata$hv4b14 = factor(hv4b14)
newdata$hv4b16[hv4b15 == 0] = 0
newdata$hv4b19[hv4b18 == 0] = 0
newdata$hv4b21_2[hv4b21_1 == 0] = 0
newdata$hv4b21_3[hv4b21_1 == 0] = 0
newdata$hv4b21_4[hv4b21_1 == 0] = 0
newdata$hv4b22[hv4b21_1 == 0] = 0
newdata$hv4b22 = factor(newdata$hv4b22)

newdata$hv4c4[hv4c3 == 0] = 0
newdata$hv4c7 = factor(newdata$hv4c7)
newdata$hv4c10[hv4c9 == 0] = 0
newdata$hv4c12[hv4c11 == 0] = 0
newdata$hv4c15 = factor(newdata$hv4c15)
newdata$hv4c16a = factor(newdata$hv4c16a)
newdata$hv4c16b = factor(newdata$hv4c16b)
newdata$hv4c16c = factor(newdata$hv4c16c)
newdata$hv4c17a = factor(newdata$hv4c17a)
newdata$hv4c17b = factor(newdata$hv4c17b)
newdata$hv4c17c = factor(newdata$hv4c17c)

newdata$hv4d1a = factor(newdata$hv4d1a)
newdata$hv4d1b = factor(newdata$hv4d1b)
newdata$hv4d1e = factor(newdata$hv4d1e)
newdata$hv4d1c = factor(newdata$hv4d1c)
newdata$hv4d1d = factor(newdata$hv4d1d)
newdata$hv4d3[hv4d2 == 0] = 3
newdata$hv4d4[hv4d2 == 0] = 0
newdata$hv4d4a[hv4d4 == 0] = 0
newdata$hv4d4a = factor(newdata$hv4d4a)
newdata$hv4d5[hv4d2 == 0] = 0
newdata$hv4d6[hv4d2 == 0] = 0
newdata$hv4d7[hv4d2 == 0] = 0
newdata$hv4d9[hv4d2 == 0 | hv4d8 == 0] = 0
newdata$hv4d9a[hv4d9 == 0] = 0
newdata$hv4d9a = factor(newdata$hv4d9a)
newdata$hv4d10[hv4d2 == 0 | hv4d8 == 0] = 0
newdata$hv4d11[hv4d2 == 0 | hv4d8 == 0] = 0
newdata$hv4d11a[hv4d11 == 0] = 0
newdata$hv4d11a = factor(newdata$hv4d11a)
newdata$hv4d12[hv4d2 == 0 | hv4d8 == 0] = 0
newdata$hv4d13[hv4d2 == 0 | hv4d8 == 0] = 0
newdata$hv4d14 = factor(newdata$hv4d14)

newdata$hv4e2[newdata$hv4e2 %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$hv4e2 = factor(newdata$hv4e2)
newdata$hv4e2a[newdata$hv4e2a %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$hv4e2a = factor(newdata$hv4e2a)

newdata$hv4f1a = factor(newdata$hv4f1a)
newdata$hv4f1b = factor(newdata$hv4f1b)
newdata$hv4f1c = factor(newdata$hv4f1c)
newdata$hv4f1d = factor(newdata$hv4f1d)
newdata$hv4f1e = factor(newdata$hv4f1e)
newdata$hv4f1f = factor(newdata$hv4f1f)
newdata$hv4f1g = factor(newdata$hv4f1g)
newdata$hv4f1h = factor(newdata$hv4f1h)
newdata$hv4f1i = factor(newdata$hv4f1i)
newdata$hv4f1j = factor(newdata$hv4f1j)
newdata$hv4f1k = factor(newdata$hv4f1k)
newdata$hv4f1l = factor(newdata$hv4f1l)
newdata$hv4f2a1 = factor(newdata$hv4f2a1)
newdata$hv4f2b1 = factor(newdata$hv4f2b1)
newdata$hv4f3a = factor(newdata$hv4f3a)
newdata$hv4f3b = factor(newdata$hv4f3b)
newdata$hv4f3c = factor(newdata$hv4f3c)
newdata$hv4f3d = factor(newdata$hv4f3d)
newdata$hv4f3e = factor(newdata$hv4f3e)

newdata$hv4g1 = factor(newdata$hv4g1)
newdata$hv4g2 = factor(newdata$hv4g2)
newdata$hv4g3 = factor(newdata$hv4g3)
newdata$hv4g4 = factor(newdata$hv4g4)
newdata$hv4g5 = factor(newdata$hv4g5)
newdata$hv4g6 = factor(newdata$hv4g6)
newdata$hv4g7 = factor(newdata$hv4g7)
newdata$hv4g8 = factor(newdata$hv4g8)
newdata$hv4g9 = factor(newdata$hv4g9)
newdata$hv4g10 = factor(newdata$hv4g10)
newdata$hv4g11 = factor(newdata$hv4g11)
newdata$hv4g12 = factor(newdata$hv4g12)
newdata$hv4g13 = factor(newdata$hv4g13)
newdata$hv4g14 = factor(newdata$hv4g14)
newdata$hv4g15 = factor(newdata$hv4g15)
newdata$hv4g16 = factor(newdata$hv4g16)
newdata$hv4g17 = factor(newdata$hv4g17)
newdata$hv4g18 = factor(newdata$hv4g18)
newdata$hv4g19 = factor(newdata$hv4g19)
newdata$hv4g21[hv4g20 == 1] = 1
newdata$hv4g22[hv4g20 == 1] = 0
newdata$hv4g22 = factor(newdata$hv4g22)
newdata$hv4g23a = factor(newdata$hv4g23a)
newdata$hv4g23b = factor(newdata$hv4g23b)
newdata$hv4g23c = factor(newdata$hv4g23c)
newdata$hv4g23d = factor(newdata$hv4g23d)
newdata$hv4g23e = factor(newdata$hv4g23e)
newdata$hv4g23f = factor(newdata$hv4g23f)
newdata$hv4g23g = factor(newdata$hv4g23g)
newdata$hv4g23h = factor(newdata$hv4g23h)
newdata$hv4g23i = factor(newdata$hv4g23i)
newdata$hv4g23j = factor(newdata$hv4g23j)
newdata$hv4g23k = factor(newdata$hv4g23k)
newdata$hv4g23l = factor(newdata$hv4g23l)
newdata$hv4g23m = factor(newdata$hv4g23m)
newdata$hv4g23n = factor(newdata$hv4g23n)
newdata$hv4g24a = factor(newdata$hv4g24a)
newdata$hv4g24b = factor(newdata$hv4g24b)
newdata$hv4g24c = factor(newdata$hv4g24c)
newdata$hv4g24d = factor(newdata$hv4g24d)
newdata$hv4g24e = factor(newdata$hv4g24e)

newdata$hv4h1 = factor(newdata$hv4h1)
newdata$hv4h2 = factor(newdata$hv4h2)
newdata$hv4h3 = factor(newdata$hv4h3)
newdata$hv4h4 = factor(newdata$hv4h4)
newdata$hv4h5 = factor(newdata$hv4h5)
newdata$hv4h6 = factor(newdata$hv4h6)
newdata$hv4h7 = factor(newdata$hv4h7)

newdata$hv4j2[hv4j1 == 0] = 0
newdata$hv4j6[hv4j1 == 0] = 0
newdata$hv4j6 = factor(newdata$hv4j6)

hv4k0[hv4k0 == -4 & hv4k0b == 0] = 0
newdata$hv4k0[hv4k0 == -4 & hv4k0b == 1] = 1
newdata$hv4k1a1[hv4k1 == 0] = 0
newdata$hv4k1a2[hv4k1 == 0] = 1
newdata$hv4k2[hv4k2_per == 1 & !is.na(hv4k2) & ! is.na(hv4k2_per)] = hv4k2[hv4k2_per == 1 & !is.na(hv4k2) & ! is.na(hv4k2_per)]*7
newdata$hv4k2[hv4k2_per == 3 & !is.na(hv4k2) & ! is.na(hv4k2_per)] = hv4k2[hv4k2_per == 3 & !is.na(hv4k2) & ! is.na(hv4k2_per)]/2
newdata$hv4k2[hv4k2_per == 4 & !is.na(hv4k2) & ! is.na(hv4k2_per)] = hv4k2[hv4k2_per == 4 & !is.na(hv4k2) & ! is.na(hv4k2_per)]/4
newdata$hv4k4[hv4k3 == 0] = 0
newdata$hv4k4[hv4k4_per == 1 & !is.na(hv4k4) & ! is.na(hv4k4_per)] = hv4k4[hv4k4_per == 1 & !is.na(hv4k4) & ! is.na(hv4k4_per)]*30
newdata$hv4k4[hv4k4_per == 2 & !is.na(hv4k4) & ! is.na(hv4k4_per)] = hv4k4[hv4k4_per == 2 & !is.na(hv4k4) & ! is.na(hv4k4_per)]*4
newdata$hv4k4[hv4k4_per == 3 & !is.na(hv4k4) & ! is.na(hv4k4_per)] = hv4k4[hv4k4_per == 3 & !is.na(hv4k4) & ! is.na(hv4k4_per)]*2
newdata$hv4k4[hv4k4_per == 5 & !is.na(hv4k4) & ! is.na(hv4k4_per)] = hv4k4[hv4k4_per == 5 & !is.na(hv4k4) & ! is.na(hv4k4_per)]/12
newdata$hv4k5[hv4k5_per == 1 & !is.na(hv4k5) & ! is.na(hv4k5_per)] = hv4k5[hv4k5_per == 1 & !is.na(hv4k5) & ! is.na(hv4k5_per)]*30
newdata$hv4k5[hv4k5_per == 2 & !is.na(hv4k5) & ! is.na(hv4k5_per)] = hv4k5[hv4k5_per == 2 & !is.na(hv4k5) & ! is.na(hv4k5_per)]*4
newdata$hv4k5[hv4k5_per == 3 & !is.na(hv4k5) & ! is.na(hv4k5_per)] = hv4k5[hv4k5_per == 3 & !is.na(hv4k5) & ! is.na(hv4k5_per)]*2
newdata$hv4k5[hv4k5_per == 5 & !is.na(hv4k5) & ! is.na(hv4k5_per)] = hv4k5[hv4k5_per == 5 & !is.na(hv4k5) & ! is.na(hv4k5_per)]/12
newdata$hv4k6[newdata$hv4k6 %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$hv4k6 = factor(newdata$hv4k6)
newdata$hv4k7[newdata$hv4k7 %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$hv4k7 = factor(newdata$hv4k7)
newdata$hv4k8[newdata$hv4k8 %in% c(-9, -6, -5, -3, -2, -1)] = NA
newdata$hv4k8 = factor(newdata$hv4k8)
newdata$hv4k10[hv4k9 == 0] = 0
newdata$hv4k10a_1[hv4k10 == 0] = 0
newdata$hv4k10a_2[hv4k10 == 0] = 0
newdata$hv4k11[hv4k9 == 0] = 0
newdata$hv4k11a_1[hv4k11 == 0] = 0
newdata$hv4k11a_2[hv4k11 == 0] = 0
newdata$hv4k11a_3[hv4k11 == 0] = 0
newdata$hv4k11a_4[hv4k11 == 0] = 0
newdata$hv4k12[hv4k9 == 0] = 0
newdata$hv4k12a_1[hv4k12 == 0] = 0
newdata$hv4k12a_2[hv4k12 == 0] = 0
newdata$hv4k12a_3[hv4k12 == 0] = 0
newdata$hv4k12a_4[hv4k12 == 0] = 0
newdata$hv4k13[hv4k9 == 0] = 0
newdata$hv4k13a_1[hv4k13 == 0] = 0
newdata$hv4k13a_2[hv4k13 == 0] = 0
newdata$hv4k13a_3[hv4k13 == 0] = 0
newdata$hv4k13a_4[hv4k13 == 0] = 0
newdata$hv4k14[hv4k9 == 0] = 0
newdata$hv4k14a_1[hv4k14 == 0] = 0
newdata$hv4k14a_2[hv4k14 == 0] = 0
newdata$hv4k14a_3[hv4k14 == 0] = 0
newdata$hv4k14a_4[hv4k14 == 0] = 0

newdata$hv4l1 = factor(newdata$hv4l1)
newdata$hv4l2 = factor(newdata$hv4l2)
newdata$hv4l3 = factor(newdata$hv4l3)
newdata$hv4l4 = factor(newdata$hv4l4)
newdata$hv4l5 = factor(newdata$hv4l5)
newdata$hv4l6 = factor(newdata$hv4l6)
newdata$hv4l7 = factor(newdata$hv4l7)
newdata$hv4l8 = factor(newdata$hv4l8)
newdata$hv4l9 = factor(newdata$hv4l9)
newdata$hv4l10 = factor(newdata$hv4l10)
newdata$hv4l11 = factor(newdata$hv4l11)
newdata$hv4l12 = factor(newdata$hv4l12)
newdata$hv4l13 = factor(newdata$hv4l13)
newdata$hv4l14 = factor(newdata$hv4l14)
newdata$hv4l15 = factor(newdata$hv4l15)
newdata$hv4l16 = factor(newdata$hv4l16)
newdata$hv4l17 = factor(newdata$hv4l17)
newdata$hv4l18 = factor(newdata$hv4l18)
newdata$hv4l19 = factor(newdata$hv4l19)
newdata$hv4l20 = factor(newdata$hv4l20)
newdata$hv4l21 = factor(newdata$hv4l21)
newdata$hv4l22 = factor(newdata$hv4l22)
newdata$hv4l23 = factor(newdata$hv4l23)
newdata$hv4l24 = factor(newdata$hv4l24)
newdata$hv4l25 = factor(newdata$hv4l25)
newdata$hv4l26 = factor(newdata$hv4l26)
newdata$hv4l27 = factor(newdata$hv4l27)
newdata$hv4l28 = factor(newdata$hv4l28)
newdata$hv4l29 = factor(newdata$hv4l29)
newdata$hv4l30 = factor(newdata$hv4l30)
newdata$hv4l31 = factor(newdata$hv4l31)
newdata$hv4l32 = factor(newdata$hv4l32)
newdata$hv4l33 = factor(newdata$hv4l33)
newdata$hv4l34 = factor(newdata$hv4l34)
newdata$hv4l35 = factor(newdata$hv4l35)
newdata$hv4l36 = factor(newdata$hv4l36)
newdata$hv4l37 = factor(newdata$hv4l37)
newdata$hv4l38 = factor(newdata$hv4l38)
newdata$hv4l39 = factor(newdata$hv4l39)
newdata$hv4l40 = factor(newdata$hv4l40)
newdata$hv4l41 = factor(newdata$hv4l41)
newdata$hv4l42 = factor(newdata$hv4l42)
newdata$hv4l43 = factor(newdata$hv4l43)
newdata$hv4l44 = factor(newdata$hv4l44)
newdata$hv4l45 = factor(newdata$hv4l45)
newdata$hv4l46 = factor(newdata$hv4l46)
newdata$hv4l47 = factor(newdata$hv4l47)
newdata$hv4l48 = factor(newdata$hv4l48)
newdata$hv4l49 = factor(newdata$hv4l49)
newdata$hv4l50 = factor(newdata$hv4l50)
newdata$hv4l51 = factor(newdata$hv4l51)
newdata$hv4l52 = factor(newdata$hv4l52)
newdata$hv4l53 = factor(newdata$hv4l53)
newdata$hv4l54 = factor(newdata$hv4l54)
newdata$hv4l55 = factor(newdata$hv4l55)
newdata$hv4l56 = factor(newdata$hv4l56)
newdata$hv4l57 = factor(newdata$hv4l57)
newdata$hv4l58 = factor(newdata$hv4l58)
newdata$hv4l59 = factor(newdata$hv4l59)
newdata$hv4l60 = factor(newdata$hv4l60)
newdata$hv4l61 = factor(newdata$hv4l61)
newdata$hv4l62 = factor(newdata$hv4l62)
newdata$hv4l63 = factor(newdata$hv4l63)
newdata$hv4l64 = factor(newdata$hv4l64)
newdata$hv4l65 = factor(newdata$hv4l65)
newdata$hv4l66 = factor(newdata$hv4l66)

newdata$hv4p1 = factor(newdata$hv4p1)
newdata$hv4p2 = factor(newdata$hv4p2)
newdata$hv4p3 = factor(newdata$hv4p3)
newdata$hv4p4 = factor(newdata$hv4p4)
newdata$hv4p5 = factor(newdata$hv4p5)
newdata$hv4p8 = factor(newdata$hv4p8)
newdata$hv4p9 = factor(newdata$hv4p9)

newdata$hv4r10a_1[hv4r10 == 0] = 0
newdata$hv4r10a_2[hv4r10 == 0] = 0
newdata$hv4r10a_3[hv4r10 == 0] = 0
newdata$hv4r10a_4[hv4r10 == 0] = 0
newdata$hv4r10a_5[hv4r10 == 0] = 0
newdata$hv4r10a_6[hv4r10 == 0] = 0
newdata$hv4r10a_7[hv4r10 == 0] = 0
newdata$hv4r10a_8[hv4r10 == 0] = 0
newdata$hv4r10a_9[hv4r10 == 0] = 0
newdata$hv4r10a_10[hv4r10 == 0] = 0
newdata$hv4r10a_11[hv4r10 == 0] = 0

newdata$hv4s2 = factor(newdata$hv4s2)
newdata$hv4s3 = factor(newdata$hv4s4)
newdata$hv4s4 = factor(newdata$hv4s4)

newdata$hv4u1 = factor(newdata$hv4u1)
newdata$hv4u2 = factor(newdata$hv4u2)
newdata$hv4u3 = factor(newdata$hv4u3)
newdata$hv4u4 = factor(newdata$hv4u4)
newdata$hv4u5 = factor(newdata$hv4u5)
newdata$hv4u6 = factor(newdata$hv4u6)
newdata$hv4u7 = factor(newdata$hv4u7)

drop = which(names(newdata) %in% c("hv4a2_ot1", "hv4a8_ot", "hv4a10_ot", "hv4a20", "hv4a21a1_mo", "hv4a21a1_yr",
                                   "hv4a21b1ot1", "hv4a21c1ot1", "hv4a21d1_ot", "hv4a21e1", "hv4a21a2_mo", "hv4a21a2_yr",
                                   "hv4a21b2ot1", "hv4a21c2ot1", "hv4a21d2_ot", "hv4a21e2", "hv4a21a3_mo", "hv4a21a3_yr",
                                   "hv4a21d3_ot", "hv4b12min", "hv4b12ampm", "hv4b14_6ot", "hv4b14_7ot","hv4d2", "hv4d8", "hv4c_d8",
                                   "hv4d17_ot", "hv4e5_ot", "hv4f2a1_ot1", "hv4f2a1_ot2", "hv4f2b1_ot1", "hv4f2b1_ot2", 
                                   "hv4g20_ot","hv4g22_ot", "hv4j3_mo", "hv4j3_yr", "hv4j3a", "hv4j5a_ot", "hv4j7_ot", "hv4j11_ot",
                                   "hv4k0a", "hv4k0b", "hv4k2_per", "hv4k2per_ot", "hv4k2a", "hv4k4_per", "hv4k4per_ot", "hv4k4a","hv4k5_per", "hv4k5per_ot", "hv4k5a", "hv4k8_ot", 
                                   "hv4k13_3oth", "hv4k4_expen", "hv4k2_expen", "hv4k5_expen", "hv4k6_ot", "hv4k13a_ot1", "hv4k13a_ot2",
                                   "hv4k10a_ot1","hv4k10a_ot2", "hv4k11a_ot1", "hv4k11a_ot2", "hv4k12a_ot1", "hv4k12a_ot2",
                                   "hv4k14a_ot1", "hv4k14a_ot2", "hv4p6_ot","hv4p8_ot1", "hv4p10","hv4r10a", "hv4r10a_ot1", "hv4r10a_ot2",
                                   "hv4s1_ot1", "hv4s1_ot2", "hv4s5_ot1_1", "hv4s5_ot1_2", "hv4s5_ot2_1", "hv4v8_ot", "hv4v9_ot", "hv4v9",
                                   "hv4cwtalone", "hv4cwtkg", "hv4bmiz", "hv4c_p10", "hv4haz", "hv4mflag", "hv4ovscale", "hv4mmis_wt", "hv4mmis_ht", "hv4mwtkg", "hv4selfht","hv4selfwt",
                                   "hv4waz","hv4whz","agemo1_c", "hv4misppvt"))
newdata = newdata[,-drop]  #note that if you need to drop more, add them to the above, or replace names(data) with names(newdata), or indices won't line up.


#########
#Output cleaned data
#########
write.csv(newdata, file = outname, row.names = F)
var.classes = sapply(newdata, class)
save(var.classes, file = "../Data/Wave4_clean_class.RData")
