library(dbarts)

outcomes = read.csv('../Data/train.csv')
outnames = c("GPA", "GRIT", "HDSHP", "EVICT", "LAYOFF", "JOB")

extractKeepVars <- function(fit, data, varclasses,num = 200){
  keepVars = rep(NA, length(varclasses))
  keeps = apply(fit$varcount, 2, mean)
  cutoff = num/length(keeps)
  
  current = 1
  for(i in 1:length(varclasses)){
    if(varclasses[i] == "factor" & nlevels(data[,i]) !=2){
      nlev = nlevels(data[,i]) - sum(tabulate(match(data[,i], levels(data[,i])))==0)
      keepVars[i] = max(keeps[current:(current+nlev-1)]) > cutoff
      current = current + nlev
    }else{
      keepVars[i] = keeps[current] > cutoff
      current = current + 1
    }
  }
  return(keepVars)
}
vclass = "integer"
names(vclass)[1] = "challengeID"
for(cut in c(300, 350, 400, 450, 500)){
  if(cut == 200){
    for(wave in 1:5){
      load(paste("../Data/Wave", wave, "_clean_class.RData", sep = ""))
      data = read.csv(paste("../Data/Wave", wave, "_clean_median.csv", sep = ""), colClasses = var.classes)
      vclass = c(vclass, var.classes[-1])
      
      if(wave == 1){
        dataset = data
      }else{
        dataset = cbind(dataset, data[,-1])
      }
    }
    set.seed(12345)
    newOrder = c(1,sample(2:dim(dataset)[2]))
    data = dataset[,newOrder]
    vclass = vclass[newOrder]
  }
  for(i in 1:6){
    
    if(cut > 200){
      load(paste("../Data/Cut", cut-50,"_", outnames[i], "_classRand.csv", sep = ""))
      data = read.csv(paste("../Data/Cut", cut-50,"_", outnames[i], "_cumRand.csv", sep = ""), colClasses = var.classes)
      vclass = var.classes
    }
    out = outcomes[,i+1]
    set.seed(1100)

    train.data = data[data$challengeID %in% outcomes$challengeID,-1]
    fit.cols = c(1:200)
    end = 0
    if(!is.null(dim(train.data)) && max(fit.cols) >= dim(train.data)[2]){
      fit.cols = min(fit.cols):dim(train.data)[2] 
      end = end + 1
    }

    keeps <- 1
    while(end < 2 & !is.null(dim(train.data))){
      fit = bart(x.train = train.data[,fit.cols], y.train = out)
      keeps = c(keeps, which(extractKeepVars(fit, train.data[,fit.cols], vclass[fit.cols+1], cut)==TRUE)+min(fit.cols))
      fit.cols = fit.cols + 200
      if(dim(train.data)[2]-max(fit.cols)==1) fit.cols = c(fit.cols, dim(train.data)[2])
      if(max(fit.cols) >= dim(train.data)[2]){
        fit.cols = min(fit.cols):dim(train.data)[2] 
        end = end + 1
      }
    }
    sub.data = data[,unique(keeps)]
    var.classes = vclass[unique(keeps)]
    save(var.classes, file = paste("../Data/Cut", cut,"_", outnames[i], "_classRand.csv", sep = ""))
    write.csv(sub.data, file = paste("../Data/Cut", cut,"_", outnames[i], "_cumRand.csv", sep = ""), row.names = F)
  }
}