library(horseshoe)

outcomes = read.csv('../Data/train.csv')
extractKeepVars <- function(fit, x,data, varclasses){
  keepVars = rep(NA, length(varclasses))
  keeps = HS.var.select(fit,x,method = "intervals")
  
  current = 1
  for(i in 1:length(varclasses)){
    if(varclasses[i] == "factor" & nlevels(data[,i]) !=2){
      nlev = nlevels(data[,i]) - sum(tabulate(match(data[,i], levels(data[,i])))==0)
      keepVars[i] = max(keeps[current:(current+nlev-1)]) > 0
      current = current + nlev - 1
    }else{
      keepVars[i] = keeps[current] == 1
      current = current + 1
    }
  }
  return(keepVars)
}


for(wave in 1:5){
  load(paste("../Data/Wave", wave, "_clean_class.RData", sep = ""))
  data = read.csv(paste("../Data/Wave", wave, "_clean_median.csv", sep = ""), colClasses = var.classes)
  
  train.data = data[data$challengeID %in% outcomes$challengeID,]
  set.seed(1100)
  
  if(dim(train.data)[2] < 200){
    fit.cols = -1
    x = model.matrix(outcomes$gpa[!is.na(outcomes$gpa)]~., data = train.data[!is.na(outcomes$gpa),fit.cols])[,-1]
    fit = horseshoe(y = outcomes$gpa[!is.na(outcomes$gpa)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
    sub.data = data[,c(1,which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GPAhshoe.csv", sep = ""), row.names = F)
    
    x = model.matrix(outcomes$grit[!is.na(outcomes$grit)]~., data = train.data[!is.na(outcomes$grit),fit.cols])[,-1]
    fit = horseshoe(y = outcomes$grit[!is.na(outcomes$grit)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
    sub.data = data[,c(1,which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GRIThshoe.csv", sep = ""), row.names = F)
    
    x = model.matrix(outcomes$materialHardship[!is.na(outcomes$materialHardship)]~., data = train.data[!is.na(outcomes$materialHardship),fit.cols])[,-1]
    fit = horseshoe(y = outcomes$materialHardship[!is.na(outcomes$materialHardship)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
    sub.data = data[,c(1,which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_HDSHPhshoe.csv", sep = ""), row.names = F)
    
    x = model.matrix(outcomes$eviction[!is.na(outcomes$eviction)]~., data = train.data[!is.na(outcomes$eviction),fit.cols])[,-1]
    fit = horseshoe(y = outcomes$eviction[!is.na(outcomes$eviction)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
    sub.data = data[,c(1,which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_EVICThshoe.csv", sep = ""), row.names = F)
    
    x = model.matrix(outcomes$layoff[!is.na(outcomes$layoff)]~., data = train.data[!is.na(outcomes$layoff),fit.cols])[,-1]
    fit = horseshoe(y = outcomes$layoff[!is.na(outcomes$layoff)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
    sub.data = data[,c(1,which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_LAYOFFhshoe.csv", sep = ""), row.names = F)
    
    x = model.matrix(outcomes$jobTraining[!is.na(outcomes$jobTraining)]~., data = train.data[!is.na(outcomes$jobTraining),fit.cols])[,-1]
    fit = horseshoe(y = outcomes$jobTraining[!is.na(outcomes$jobTraining)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
    sub.data = data[,c(1,which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_JOBhshoe.csv", sep = ""), row.names = F)
  }else{
    train.data = train.data[,-1]
    var.classes = var.classes[-1]
    fit.cols = c(1:200)
    end = 0
    keepGPA <- keepGRIT <- keepHARD <- keepEVICT <- keepLAYOFF <- keepJOB <- 1
    while(end < 2){
      x = model.matrix(outcomes$gpa[!is.na(outcomes$gpa)]~., data = train.data[!is.na(outcomes$gpa),fit.cols])[,-1]
      fit = horseshoe(y = outcomes$gpa[!is.na(outcomes$gpa)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
      keepGPA = c(keepGPA, which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))
      
      x = model.matrix(outcomes$grit[!is.na(outcomes$grit)]~., data = train.data[!is.na(outcomes$grit),fit.cols])[,-1]
      fit = horseshoe(y = outcomes$grit[!is.na(outcomes$grit)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
      keepGRIT = c(keepGRIT, which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))
      
      x = model.matrix(outcomes$materialHardship[!is.na(outcomes$materialHardship)]~., data = train.data[!is.na(outcomes$materialHardship),fit.cols])[,-1]
      fit = horseshoe(y = outcomes$materialHardship[!is.na(outcomes$materialHardship)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
      keepHARD = c(keepHARD, which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      x = model.matrix(outcomes$eviction[!is.na(outcomes$eviction)]~., data = train.data[!is.na(outcomes$eviction),fit.cols])[,-1]
      fit = horseshoe(y = outcomes$eviction[!is.na(outcomes$eviction)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
      keepEVICT = c(keepEVICT, which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))
      
      x = model.matrix(outcomes$layoff[!is.na(outcomes$layoff)]~., data = train.data[!is.na(outcomes$layoff),fit.cols])[,-1]
      fit = horseshoe(y = outcomes$layoff[!is.na(outcomes$layoff)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
      keepLAYOFF = c(keepLAYOFF, which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))
      
      x = model.matrix(outcomes$jobTraining[!is.na(outcomes$jobTraining)]~., data = train.data[!is.na(outcomes$jobTraining),fit.cols])[,-1]
      fit = horseshoe(y = outcomes$jobTraining[!is.na(outcomes$jobTraining)],x, method.tau = "halfCauchy", method.sigma = "Jeffreys")
      keepJOB = c(keepJOB, which(extractKeepVars(fit, x, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))
      
      fit.cols = fit.cols + 200
      if(dim(train.data)[2]-max(fit.cols)==1) fit.cols = c(fit.cols, dim(train.data)[2])
      if(max(fit.cols) >= dim(train.data)[2]){
        fit.cols = min(fit.cols):dim(train.data)[2] 
        end = end+1
      }
    }
    sub.data = data[,keepGPA]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GPAhshoe.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepGRIT]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GRIThshoe.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepHARD]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_HDSHPhshoe.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepEVICT]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_EVICThshoe.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepLAYOFF]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_LAYOFFhshoe.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepJOB]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_JOBhshoe.csv", sep = ""), row.names = F)
  }
}
