library(glmnet)

outcomes = read.csv('../Data/train.csv')
extractKeepVars <- function(fit, data, varclasses){
  keepVars = rep(NA, length(varclasses))
  keeps = abs(coef(fit, s = "lambda.1se")[-1])
  
  current = 1
  for(i in 1:length(varclasses)){
    if(varclasses[i] == "factor" & nlevels(data[,i]) !=2){
      nlev = nlevels(data[,i]) - sum(tabulate(match(data[,i], levels(data[,i])))==0)
      keepVars[i] = max(keeps[current:(current+nlev-1)]) > 0
      current = current + nlev
    }else{
      keepVars[i] = keeps[current] > 0
      current = current + 1
    }
  }
  return(keepVars)
}


for(wave in 1:5){
  load(paste("../Data/Wave", wave, "_clean_class.RData", sep = ""))
  data = read.csv(paste("../Data/Wave", wave, "_clean_median.csv", sep = ""), colClasses = var.classes)
  
  train.data = data[data$challengeID %in% outcomes$challengeID,]
  set.seed(1100)
  
  if(dim(train.data)[2] < 200){
    fit.cols = -1
    x = sparse.model.matrix(outcomes$gpa[!is.na(outcomes$gpa)]~., data = train.data[!is.na(outcomes$gpa),fit.cols])
    fit = cv.glmnet(x[,-1], outcomes$gpa[!is.na(outcomes$gpa)], thresh = 1e-4, type.measure="mae")
    sub.data = data[,c(1,extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GPAlasso.csv", sep = ""), row.names = F)
    
    x = sparse.model.matrix(outcomes$grit[!is.na(outcomes$grit)]~., data = train.data[!is.na(outcomes$grit),fit.cols])
    fit = cv.glmnet(x[,-1], outcomes$grit[!is.na(outcomes$grit)], thresh = 1e-4, type.measure="mae")
    sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GRITlasso.csv", sep = ""), row.names = F)
    
    x = sparse.model.matrix(outcomes$materialHardship[!is.na(outcomes$materialHardship)]~., data = train.data[!is.na(outcomes$materialHardship),fit.cols])
    fit = cv.glmnet(x[,-1], outcomes$materialHardship[!is.na(outcomes$materialHardship)], thresh = 1e-4, type.measure="mae")
    sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_HDSHPlasso.csv", sep = ""), row.names = F)
    
    x = sparse.model.matrix(outcomes$eviction[!is.na(outcomes$eviction)]~., data = train.data[!is.na(outcomes$eviction),fit.cols])
    fit = cv.glmnet(x[,-1], outcomes$eviction[!is.na(outcomes$eviction)], family = "binomial", thresh = 1e-4, type.measure="mae")
    sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_EVICTlasso.csv", sep = ""), row.names = F)
    
    x = sparse.model.matrix(outcomes$layoff[!is.na(outcomes$layoff)]~., data = train.data[!is.na(outcomes$layoff),fit.cols])
    fit = cv.glmnet(x[,-1], outcomes$layoff[!is.na(outcomes$layoff)], family = "binomial", thresh = 1e-4, type.measure="mae")
    sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_LAYOFFlasso.csv", sep = ""), row.names = F)
    
    x = sparse.model.matrix(outcomes$jobTraining[!is.na(outcomes$jobTraining)]~., data = train.data[!is.na(outcomes$jobTraining),fit.cols])
    fit = cv.glmnet(x[,-1], outcomes$jobTraining[!is.na(outcomes$jobTraining)], family = "binomial", thresh = 1e-4)
    sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_JOBlasso.csv", sep = ""), row.names = F)
  }else{
    fit.cols = c(1:200)
    end = 0
    keepGPA <- keepGRIT <- keepHARD <- keepEVICT <- keepLAYOFF <- keepJOB <- 1
    while(end < 2){
      x = sparse.model.matrix(outcomes$gpa[!is.na(outcomes$gpa)]~., data = train.data[!is.na(outcomes$gpa),fit.cols])
      fit = cv.glmnet(x[,-1], outcomes$gpa[!is.na(outcomes$gpa)], thresh = 1e-4, type.measure="mae")
      keepGPA = c(keepGPA, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      x = sparse.model.matrix(outcomes$grit[!is.na(outcomes$grit)]~., data = train.data[!is.na(outcomes$grit),fit.cols])
      fit = cv.glmnet(x[,-1], outcomes$grit[!is.na(outcomes$grit)], thresh = 1e-4, type.measure="mae")
      keepGRIT = c(keepGRIT, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      x = sparse.model.matrix(outcomes$materialHardship[!is.na(outcomes$materialHardship)]~., data = train.data[!is.na(outcomes$materialHardship),fit.cols])
      fit = cv.glmnet(x[,-1], outcomes$materialHardship[!is.na(outcomes$materialHardship)], thresh = 1e-4, type.measure="mae")
      keepHARD = c(keepHARD, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      x = sparse.model.matrix(outcomes$eviction[!is.na(outcomes$eviction)]~., data = train.data[!is.na(outcomes$eviction),fit.cols])
      fit = cv.glmnet(x[,-1], outcomes$eviction[!is.na(outcomes$eviction)], family = "binomial", thresh = 1e-4, type.measure="mae")
      keepEVICT = c(keepEVICT, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      x = sparse.model.matrix(outcomes$layoff[!is.na(outcomes$layoff)]~., data = train.data[!is.na(outcomes$layoff),fit.cols])
      fit = cv.glmnet(x[,-1], outcomes$layoff[!is.na(outcomes$layoff)], family = "binomial", thresh = 1e-4, type.measure="mae")
      keepLAYOFF = c(keepLAYOFF, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      x = sparse.model.matrix(outcomes$jobTraining[!is.na(outcomes$jobTraining)]~., data = train.data[!is.na(outcomes$jobTraining),fit.cols])
      fit = cv.glmnet(x[,-1], outcomes$jobTraining[!is.na(outcomes$jobTraining)], family = "binomial", thresh = 1e-4, type.measure="mae")
      keepJOB = c(keepJOB, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols)-1)
      
      fit.cols = fit.cols + 200
      if(dim(train.data)[2]-max(fit.cols)==1) fit.cols = c(fit.cols, dim(train.data)[2])
      if(max(fit.cols) >= dim(train.data)[2]){
        fit.cols = min(fit.cols):dim(train.data)[2] 
        end = end+1
      }
    }
    sub.data = data[,keepGPA]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GPAlasso.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepGRIT]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_GRITlasso.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepHARD]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_HDSHPlasso.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepEVICT]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_EVICTlasso.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepLAYOFF]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_LAYOFFlasso.csv", sep = ""), row.names = F)
    
    sub.data = data[,keepJOB]
    write.csv(sub.data, file = paste("../Data/Wave", wave, "_JOBlasso.csv", sep = ""), row.names = F)
  }
}
