library(dbarts)

outcomes = read.csv('../Data/train.csv')

extractKeepVars <- function(fit, data, varclasses){
  keepVars = rep(NA, length(varclasses))
  keeps = apply(fit$varcount, 2, mean)
  cutoff = 400/length(keeps)
  
  current = 1
  for(i in 1:length(varclasses)){
    if(varclasses[i] == "factor" & nlevels(data[,i]) !=2){
      nlev = nlevels(data[,i]) - sum(tabulate(match(data[,i], levels(data[,i])))==0)
      keepVars[i] = max(keeps[current:(current+nlev-1)]) > cutoff
      current = current + nlev
    }else{
      keepVars[i] = keeps[current] > cutoff
      current = current + 1
    }
  }
  return(keepVars)
}


for(wave in 1:5){
load(paste("../Data/Wave", wave, "_clean_class.RData", sep = ""))
data = read.csv(paste("../Data/Wave", wave, "_clean_median.csv", sep = ""), colClasses = var.classes)
set.seed(1100)

newOrder = c(1,sample(2:dim(data)[2]))
data = data[,newOrder]
var.classes = var.classes[newOrder][-1]

train.data = data[data$challengeID %in% outcomes$challengeID,-1]

if(dim(train.data)[2] < 300){
  fit.cols <- 1:dim(train.data)[2]

  fit = bart(x.train = train.data, y.train = outcomes$gpa)
  sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_GPAbart_rand.csv", sep = ""), row.names = F)
  
  fit = bart(x.train = train.data, y.train = outcomes$grit)
  sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_GRITbart_rand.csv", sep = ""), row.names = F)
  
  fit = bart(x.train = train.data, y.train = outcomes$materialHardship)
  sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_HDSHPbart_rand.csv", sep = ""), row.names = F)
  
  fit = bart(x.train = train.data, y.train = outcomes$eviction)
  sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_EVICTbart_rand.csv", sep = ""), row.names = F)
  
  fit = bart(x.train = train.data, y.train = outcomes$layoff)
  sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_LAYOFFbart_rand.csv", sep = ""), row.names = F)
  
  fit = bart(x.train = train.data, y.train = outcomes$jobTraining)
  sub.data = data[,c(1,which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+1)]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_JOBbart_rand.csv", sep = ""), row.names = F)
}else{
  fit.cols = c(1:300)
keepGPA <- keepGRIT <- keepHARD <- keepEVICT <- keepLAYOFF <- keepJOB <- 1
	while(max(fit.cols) < dim(train.data)[2]){
	fit = bart(x.train = train.data[,fit.cols], y.train = outcomes$gpa)
keepGPA = c(keepGPA, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))

fit = bart(x.train = train.data[,fit.cols], y.train = outcomes$grit)
keepGRIT = c(keepGRIT, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))

fit = bart(x.train = train.data[,fit.cols], y.train = outcomes$materialHardship)
keepHARD = c(keepHARD, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))

fit = bart(x.train = train.data[,fit.cols], y.train = outcomes$eviction)
keepEVICT = c(keepEVICT, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))

fit = bart(x.train = train.data[,fit.cols], y.train = outcomes$layoff)
keepLAYOFF = c(keepLAYOFF, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))

fit = bart(x.train = train.data[,fit.cols], y.train = outcomes$jobTraining)
keepJOB = c(keepJOB, which(extractKeepVars(fit, train.data[,fit.cols], var.classes[fit.cols])==TRUE)+min(fit.cols))

fit.cols = fit.cols + 300
if(max(fit.cols) > dim(train.data)[2]) fit.cols = min(fit.cols):dim(train.data)[2] 
  }
  sub.data = data[,keepGPA]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_GPAbart_rand.csv", sep = ""), row.names = F)
  
  sub.data = data[,keepGRIT]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_GRITbart_rand.csv", sep = ""), row.names = F)
  
  sub.data = data[,keepHARD]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_HDSHPbart_rand.csv", sep = ""), row.names = F)
  
  sub.data = data[,keepEVICT]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_EVICTbart_rand.csv", sep = ""), row.names = F)
  
  sub.data = data[,keepLAYOFF]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_LAYOFFbart_rand.csv", sep = ""), row.names = F)
  
  sub.data = data[,keepJOB]
  write.csv(sub.data, file = paste("../Data/Wave", wave, "_JOBbart_rand.csv", sep = ""), row.names = F)
}
}
