library(ggplot2)
require(gridExtra)
library(ggpubr)
require(Rmisc)
require(dplyr)


filepath = "../Data/ResultsData.csv"
df = read.csv(filepath, nrows = 600)
attach(df)

#MSE and standardized RMSE by outcome
finalsummary1.1 = ggplot(df[!is.na(df$finalMSE),], aes(y=finalMSE, x = outcome)) + 
  geom_boxplot()+
  scale_y_continuous(limits = c(0,0.5))+
  labs(y = "Mean squared error", x = "Outcome")+
  theme_classic()

finalsummary1.2 = ggplot(df[!is.na(df$finalRMSEstd),], aes(y=finalRMSEstd, x = outcome)) + 
  geom_boxplot()+
  labs(y = "Standardized root mean squared error", x = "Outcome")+
  scale_y_continuous(limits = c(0.6,1.1))+
  theme_classic()

figure <- ggarrange(finalsummary1.1, finalsummary1.2, labels = c("A", "B"), ncol = 2, nrow = 1)

annotate_figure(figure, top = text_grob("Variation in prediction error by outcome",
                                        face = "bold", size = 14))
ggsave("../Output/Figure2.pdf")

#error by variable selection method, after adjusting for outcome differences
finalsummary1.3 = ggplot(df[!is.na(df$finalMSE)& dataUsed == "All" &outcome %in% c("Evict", "Job", "Layoff"),], aes(y=lm(finalMSE~outcome)$resid, x = varSelect)) + 
  geom_violin()+geom_boxplot(width = 0.1)+
  labs(y = "Residual MSE (adjusted for outcome)", x = "Variable selection method")+
  ggtitle("Binary outcomes")+
  geom_hline(aes(yintercept = 0), linetype = "dotted", colour = "red") +
  stat_summary(fun.y = mean, geom = "errorbar", aes(ymax = ..y.., ymin = ..y..),
               width = .75, linetype = "dashed") +
  theme_classic()

finalsummary1.4 = ggplot(df[!is.na(df$finalRMSEstd)& dataUsed == "All" & outcome %in% c("GPA", "Grit", "Hdshp"),], aes(y=lm(finalRMSEstd~outcome)$resid, x = varSelect)) + 
  geom_violin()+geom_boxplot(width = 0.1)+
  labs(y = "Residual sRMSE (adjusted for outcome)", x = "Variable selection method")+
  ggtitle("Continuous outcomes")+
  geom_hline(aes(yintercept = 0), linetype = "dotted", colour = "red") +
  stat_summary(fun.y = mean, geom = "errorbar", aes(ymax = ..y.., ymin = ..y..),
               width = .75, linetype = "dashed") +
  theme_classic()

figure <- ggarrange(finalsummary1.3, finalsummary1.4, labels = c("A", "B"), ncol = 2, nrow = 1)

annotate_figure(figure, top = text_grob("Residual variation by variable selection method",
                                        face = "bold", size = 14))

ggsave("../Output/Figure3.pdf")

##Tree by predictor plot

finalsummary1.5 = ggplot(df[!is.na(df$finalMSE) & dataUsed == "All" &outcome %in% c("Evict", "Job", "Layoff"),], aes(x=numtrees/(numVar),y=lm(finalMSE~outcome)$resid)) +
  stat_smooth(method="loess", span=0.6, se=TRUE) +
  labs(y = "Residual MSE", x = "Tree to predictor ratio (binary outcomes)") +
  scale_x_continuous(trans = "log2") +  
  facet_grid(.~varSelect)+
  theme_bw()


finalsummary1.6 = ggplot(df[!is.na(df$finalRMSEstd) & dataUsed == "All" & outcome %in% c("GPA", "Grit", "Hdshp"),], aes(x=numtrees/(numVar),y=lm(finalRMSEstd~outcome)$resid)) +
  stat_smooth(method="loess", span=0.6, se=TRUE) +
  labs(y = "Residual sRMSE", x = "Tree to predictor ratio (continuous outcomes)") +
  scale_x_continuous(trans = "log2") +
  facet_grid(.~varSelect)+
  theme_bw()

figure <- ggarrange(finalsummary1.5, finalsummary1.6, labels = c("A", "B"), ncol = 1, nrow = 2)

annotate_figure(figure, top = text_grob("Prediction error after adjustment for outcome",
                                        face = "bold", size = 14))

ggsave("../Output/Figure6.pdf")

######
##Data for Table 1
## regression results for contributions
treeRatio = log(numtrees/numVar)

fitBin = lm(finalMSE~outcome+varSelect +treeRatio, subset = (numVar > 0 & dataUsed == "All"&outcome %in% c("Evict", "Job", "Layoff")))
summary(fitBin)

fitCont = lm(finalRMSEstd~outcome+varSelect+(varSelect == "lasso")*treeRatio + (varSelect == "lasso")*I(treeRatio^2), subset = (numVar > 0 & dataUsed == "All"&outcome %in% c("GPA", "Grit", "Hdshp")))
summary(fitCont)
