library(dbarts)

binaryMean <- function(x) {
  px = pnorm(x)
  return(apply(px, 2, mean))
}

k <- c(1, 2, 4, 8)
outcomes = read.csv('../Data/train.csv')

for (method in c(
  "lasso_rand",
  "lasso",
  "bglm_rand",
  "bglm",
  "hshoe_rand",
  "hshoe",
  "bart",
  "bart_rand"
)) {
  for (ntree in c(500, 1000, 2500, 5000, 7500, 10000)) {
    predictions = data.frame(
      challengeID = data[, 1],
      gpa = NA,
      grit = NA,
      materialHardship = NA,
      eviction = NA,
      layoff = NA,
      jobTraining = NA
    )
    i = 1
    for (outcome in c("GPA", "GRIT", "HDSHP")) {
      i = i + 1
      
      file1 = paste("../Data/Wave1_", outcome, method, ".csv", sep = "")
      file2 = paste("../Data/Wave2_", outcome, method, ".csv", sep = "")
      file3 = paste("../Data/Wave3_", outcome, method, ".csv", sep = "")
      file4 = paste("../Data/Wave4_", outcome, method, ".csv", sep = "")
      file5 = paste("../Data/Wave5_", outcome, method, ".csv", sep = "")
      
      data1 = read.csv(file1)
      data2 = read.csv(file2)
      data3 = read.csv(file3)
      data4 = read.csv(file4)
      data5 = read.csv(file5)
      
      data = cbind(data1, data2[-1], data3[,-1], data4[,-1], data5[,-1])
      train.data = data[data$challengeID %in% outcomes$challengeID,]
      
      set.seed(47710)
      fit = bart(
        x.train = train.data[,-1],
        x.test = data[,-1],
        y.train = outcomes[, i],
        ntree = ntree
      )
      pred = fit$yhat.test.mean
      if (outcome == "HDSHP")
        pred[pred < 0] = 0
      predictions[, i] = pred
    }
    for (outcome in c("EVICT", "LAYOFF", "JOB")) {
      i = i + 1
      
      file1 = paste("../Data/Wave1_", outcome, method, ".csv", sep = "")
      file2 = paste("../Data/Wave2_", outcome, method, ".csv", sep = "")
      file3 = paste("../Data/Wave3_", outcome, method, ".csv", sep = "")
      file4 = paste("../Data/Wave4_", outcome, method, ".csv", sep = "")
      file5 = paste("../Data/Wave5_", outcome, method, ".csv", sep = "")
      
      data1 = read.csv(file1)
      data2 = read.csv(file2)
      data3 = read.csv(file3)
      data4 = read.csv(file4)
      data5 = read.csv(file5)
      
      data = cbind(data1, data2[-1], data3[,-1], data4[,-1], data5[,-1])
      train.data = data[data$challengeID %in% outcomes$challengeID,]
      
      set.seed(47710)
      xval <-
        dbarts::xbart(
          train.data[,-1],
          outcomes[, i],
          k = k,
          n.trees = 50L,
          n.threads = 1L
        )
      bestk <- k[which.min(apply(xval, 2L, mean))]
      fit <-
        dbarts::bart(
          x.train = train.data[,-1],
          x.test = data[,-1],
          y.train = outcomes$eviction,
          k = bestk,
          ntree = ntree
        )
      pred = binaryMean(fit$yhat.test)
      predictions[, i] = pred
    }
    write.csv(
      predictions,
      paste("../Output/prediction_", method, "_nt", ntree, ".csv", sep = "")
    )
  }
  for (wave in c(1:5, "_constr")) {
    predictions = data.frame(
      challengeID = data[, 1],
      gpa = NA,
      grit = NA,
      materialHardship = NA,
      eviction = NA,
      layoff = NA,
      jobTraining = NA
    )
    i = 1
    for (outcome in c("GPA", "GRIT", "HDSHP")) {
      i = i + 1
      file1 = paste("../Data/Wave", wave, "_", outcome, method, ".csv", sep = "")
      data = read.csv(file1)
      train.data = data[data$challengeID %in% outcomes$challengeID,]
      
      set.seed(47710)
      fit = bart(
        x.train = train.data[,-1],
        x.test = data[,-1],
        y.train = outcomes[, i],
        ntree = 500L
      )
      pred = fit$yhat.test.mean
      if (outcome == "HDSHP")
        pred[pred < 0] = 0
      predictions[, i] = pred
    }
    for (outcome in c("EVICT", "LAYOFF", "JOB")) {
      i = i + 1
      
      file1 = paste("../Data/Wave", wave, "_", outcome, method, ".csv", sep = "")
      data = read.csv(file1)
      train.data = data[data$challengeID %in% outcomes$challengeID,]
      
      set.seed(47710)
      xval <-
        dbarts::xbart(
          train.data[,-1],
          outcomes[, i],
          k = k,
          n.trees = 50L,
          n.threads = 1L
        )
      bestk <- k[which.min(apply(xval, 2L, mean))]
      fit <-
        dbarts::bart(
          x.train = train.data[,-1],
          x.test = data[,-1],
          y.train = outcomes$eviction,
          k = bestk,
          ntree = 500L
        )
      pred = binaryMean(fit$yhat.test)
      predictions[, i] = pred
    }
    write.csv(
      predictions,
      paste("../Output/prediction_",method, "_Wave",wave,".csv",sep = "")
    )
  }
}

for (method in c("cum_rand",
                 "cum")) {
  for (ntree in c(200, 500, 1000, 2500, 5000, 7500, 10000)) {
    for (cut in c(200, 250, 300, 350, 400, 450, 500)) {
      filename = paste("../Data/Cut", cut, "_GPA_", method, ".csv", sep = "")
      data = read.csv(filename)
      train.data = data[data$challengeID %in% outcomes$challengeID, ]
      fit = bart(
        x.train = train.data[, -1],
        x.test = data[, -1],
        y.train = outcomes$gpa,
        ntree = ntree
      )
      pred.gpa = fit$yhat.test.mean
      
      filename = paste("../Data/Cut", cut, "_GRIT_", method, ".csv", sep = "")
      data = read.csv(filename)
      train.data = data[data$challengeID %in% outcomes$challengeID, ]
      fit = bart(
        x.train = train.data[, -1],
        x.test = data[, -1],
        y.train = outcomes$grit,
        ntree = ntree
      )
      pred.grit = fit$yhat.test.mean
      
      filename = paste("../Data/Cut", cut, "_HDSHP_", method, ".csv", sep = "")
      data = read.csv(filename)
      train.data = data[data$challengeID %in% outcomes$challengeID, ]
      fit = bart(
        x.train = train.data[, -1],
        x.test = data[, -1],
        y.train = outcomes$materialHardship,
        ntree = ntree
      )
      pred.hard = fit$yhat.test.mean
      pred.hard[pred.hard < 0] = 0
      
      filename = paste("../Data/Cut", cut, "_EVICT_", method, ".csv", sep = "")
      data = read.csv(filename)
      train.data = data[data$challengeID %in% outcomes$challengeID, ]
      xval <-
        dbarts::xbart(
          train.data[, -1],
          outcomes$eviction,
          k = k,
          n.trees = 50L,
          n.threads = 1L
        )
      bestk <- k[which.min(apply(xval, 2L, mean))]
      fit <-
        dbarts::bart(
          x.train = train.data[, -1],
          x.test = data[, -1],
          y.train = outcomes$eviction,
          k = bestk,
          ntree = ntree
        )
      pred.evict = binaryMean(fit$yhat.test)
      
      filename = paste("../Data/Cut", cut, "_LAYOFF_", method, ".csv", sep = "")
      data = read.csv(filename)
      train.data = data[data$challengeID %in% outcomes$challengeID, ]
      xval <-
        dbarts::xbart(
          train.data[, -1],
          outcomes$layoff,
          k = k,
          n.trees = 50L,
          n.threads = 1L
        )
      bestk <- k[which.min(apply(xval, 2L, mean))]
      fit = dbarts::bart(
        x.train = train.data[, -1],
        x.test = data[, -1],
        y.train = outcomes$layoff,
        k = bestk,
        ntree = ntree
      )
      pred.layoff = binaryMean(fit$yhat.test)
      
      filename = paste("../Data/Cut", cut, "_JOB_", method, ".csv", sep = "")
      data = read.csv(filename)
      train.data = data[data$challengeID %in% outcomes$challengeID, ]
      xval <-
        dbarts::xbart(
          train.data[, -1],
          outcomes$jobTraining,
          k = k,
          n.trees = 50L,
          n.threads = 1L
        )
      bestk <- k[which.min(apply(xval, 2L, mean))]
      fit = dbarts::bart(
        x.train = train.data[, -1],
        x.test = data[, -1],
        y.train = outcomes$jobTraining,
        k = bestk,
        ntree = ntree
      )
      pred.train = binaryMean(fit$yhat.test)
      
      predictions = data.frame(
        challengeID = data[, 1],
        gpa = pred.gpa,
        grit = pred.grit,
        materialHardship = pred.hard,
        eviction = pred.evict,
        layoff = pred.layoff,
        jobTraining = pred.train
      )
      write.csv(
        predictions,
        file = paste(
          "../Output/prediction_Cut",
          cut,
          "ntree",
          ntree,
          ".csv",
          sep = ""
        ),
        row.names = F
      )
    }
  }
}
